@@ -252,28 +252,28 @@ OC.L10N.register(
     "Error" : "Fout",
     "Saved" : "Bewaar",
     "Copy link" : "Kopieer skakel",
+    "Settings" : "Instellings",
     "Dismiss" : "Ontslaan",
     "Back" : "Terug",
     "Favorite" : "Gunsteling",
     "Enter a password" : "Gee ’n wagwoord",
+    "Save" : "Stoor",
+    "Edit" : "Wysig",
+    "Password" : "Wagwoord",
+    "Login" : "Teken aan",
+    "Nickname" : "Bynaam",
+    "Client ID" : "Kliënt-ID",
     "Remove from favorites" : "Verwyder uit gunstelinge",
     "Add to favorites" : "Voeg by gunstelinge",
     "Loading" : "Laai tans..",
     "Groups" : "Groepe",
-    "Settings" : "Instellings",
     "Password protect" : "Beskerm met 'n wagwoord",
     "Close" : "Sluit",
     "Reply" : "Antwoord",
     "Remove" : "Verwyder",
     "Today" : "Vandag",
     "Yesterday" : "Gister",
-    "Save" : "Stoor",
-    "Password" : "Wagwoord",
-    "Login" : "Teken aan",
-    "Nickname" : "Bynaam",
-    "Client ID" : "Kliënt-ID",
     "Chat" : "Klets",
-    "Edit" : "Wysig",
     "Keyboard shortcuts" : "Sneltoetse",
     "Search" : "Soek",
     "Send" : "Stuur",
@@ -281,9 +281,6 @@ OC.L10N.register(
     "The password is wrong. Try again." : "Die wagwoord is verkeerd. Probeer weer.",
     "Android app" : "Android-toep",
     "iOS app" : "iOS-toep",
-    "Contacts" : "Kontakte",
-    "Guests" : "Gaste",
-    "Share link" : "Deelskakel",
-    "Cancel" : "Kanselleer"
+    "Share link" : "Deelskakel"
 },
 "nplurals=2; plural=(n != 1);");
