@@ -12,14 +12,11 @@ OC.L10N.register(
     "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "تم دعوتك للإنضمام إلى <strong>المحادثة</strong> أو <strong>المكالمة</strong>",
     "Talk" : "التحدث",
     "Guest" : "ضيف",
-    "- Spice up your messages with emojis from the emoji picker" : " - أضف على رسائلك الرموز التعبيرية",
-    "- Spice up your messages with emojis from the emoji picker {emoji}" : " - أضف على رسائلك الرموز التعبيرية {emoji}",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "مرحبا بك في التحدث نيكست كلاود!\nفي هذه المحادثة سيتم اشعارك بكل المميزات المتاحة في التحدث نيكست كلاود.",
-    "New in Talk 6" : "جديد التحدث 6",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- المتصفح مايكروسوفت ايدج و سفاري بإمكانهم الآن الانضمام لمكالمات الصوتية والفيديو",
     "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- أصبحت المحادثات الفردية مستمرة الآن ولا يمكن تحويلها إلى محادثات جماعية عن طريق الصدفة بعد الآن. أيضًا عندما يغادر أحد المشاركين المحادثة ، لا يتم حذف المحادثة تلقائيًا بعد الآن. فقط إذا غادر كلا المشاركين ، يتم حذف المحادثة من الخادم",
     "- You can now notify all participants by posting \"@all\" into the chat" : "- يمكنك الآن تنبيه جميع المشاركين بنشر \"@all\" في الدردشة",
-    "New in Talk 9" : "جديد التحدث نسخة 9",
+    "- Spice up your messages with emojis from the emoji picker" : " - أضف على رسائلك الرموز التعبيرية",
     "There are currently no commands available." : "لا يوجد اوامر في الوقت الحالي",
     "The command does not exist" : "الامر غير موجود",
     "An error occurred while running the command. Please ask an administrator to check the logs." : "خطأ اثناء استدعاء الامر، اطلب من الادارة مراجعة السجلات.",
@@ -361,6 +358,7 @@ OC.L10N.register(
     "Share a single window" : "مشاركة نافذة",
     "Show your screen" : "مشاركة الشاشة",
     "Stop screensharing" : "التوقف عن مشاركة الشاشة",
+    "Settings" : "الإعدادات",
     "Dismiss" : "الغاء",
     "No audio" : "بدون صوت",
     "Mute audio (m)" : "كتم الصوت (m)",
@@ -415,9 +413,37 @@ OC.L10N.register(
     "Conversation settings" : "اعدادات المحادثة",
     "Password protection" : "الحماية بكلمة السر",
     "Enter a password" : "إدخِل كلمة سرية",
-    "Lock conversation" : "قفل المحادثة",
+    "Copy conversation link" : "نسخ رابط المحادثة",
     "Enable lobby" : "تفعيل انتظار الاستقبال",
     "Start time (optional)" : "بداية الوقت (اختياري)",
+    "Lock conversation" : "قفل المحادثة",
+    "Save" : "حفظ",
+    "Edit" : "تعديل",
+    "Nextcloud URL" : "رابط الخادم السحابي نكست كلاود",
+    "Nextcloud user" : "عضو نكست كلاود",
+    "User password" : "كلمة مرور المستخدم",
+    "Talk conversation" : "محادثات",
+    "Team name" : "اسم الفريق",
+    "Channel name" : "اسم القناة",
+    "User name or e-mail address" : "اسم المستخدم او البريد الالكتروني",
+    "Password" : "الكلمة السرية",
+    "Server ID or name" : "معرف الخادم السحابي او الاسم",
+    "Channel ID or name" : "معرف القناة او الاسم",
+    "Channel" : "قناة",
+    "Login" : "الدخول",
+    "Chat ID" : "معرف المحادثة",
+    "Nickname" : "كنية.\nلقب.",
+    "Connection password" : "كلمة مرور الاتصال",
+    "Channel password" : "كلمة مرور القناة",
+    "Use TLS" : "استخدم TLS",
+    "Skip TLS verification" : "تجاهل تحقق من TLS",
+    "Tenant ID" : "معرف المستأجر",
+    "Client ID" : "معرف العميل",
+    "Team ID" : "معرف الفريق",
+    "Thread ID" : "معرف الموضوع",
+    "unknown state" : "حالة غير معروفة",
+    "running" : "فعال",
+    "not running" : "غير فعال",
     "Enable SIP dial-in" : "تفعيل الاتصال عبر SIP",
     "Chat notifications" : "تنبيه المحادثة",
     "Leave conversation" : "غادر المحادثة",
@@ -433,15 +459,14 @@ OC.L10N.register(
     "No search results" : "لا توجد نتائج",
     "Groups" : "المجموعات",
     "Circles" : "جماعة",
-    "Settings" : "الإعدادات",
     "Users, groups and circles" : "الاعضاء، المجموعات و الجماعات",
     "Users and groups" : "الاعضاء والمجموعات",
     "Users and circles" : "الاعضاء والجماعات",
     "Groups and circles" : "المجموعات و الجماعات",
     "Other sources" : "مصادر آخرى",
+    "An error occurred while performing the search" : "حدث خطأ اثناء البحث",
     "Creating your conversation" : "انشاء محادثتك",
     "All set" : "تم تعيين",
-    "Copy conversation link" : "نسخ رابط المحادثة",
     "Error while creating the conversation" : "حدث خطأ اثناء نسخ رابط المحادثة",
     "Link copied to the clipboard!" : "تم نسخ رابط المحادثة",
     "Create a new group conversation" : "انشاء محادثة جماعية جديدة",
@@ -451,7 +476,6 @@ OC.L10N.register(
     "Close" : "إغلاق",
     "Choose a password" : "اختر كلمة مرور",
     "Search participants" : "البحث عن مشاركين",
-    "An error occurred while performing the search" : "حدث خطأ اثناء البحث",
     "Conversation name" : "اسم المحادثة",
     "Allow guests to join via link " : "السماح بالضيوف بالانضمام عن طريق الرابط",
     "Search conversations or users" : "البحث عن المحادثات او الاعضاء",
@@ -486,34 +510,6 @@ OC.L10N.register(
     "No permission to post messages in this conversation" : "ليس لديك صلاحية لنشر رسائل في هذه المحادثة",
     "Could not post message: {errorMessage}" : "لا يمكن نشر رسالة: {errorMessage}",
     "Invalid path selected" : "تم تحديد مسار غير صحيح",
-    "Bridge with other services" : "الربط مع خدمات آخرى",
-    "Enabled" : "مفعلة",
-    "Save" : "حفظ",
-    "Nextcloud URL" : "رابط الخادم السحابي نكست كلاود",
-    "Nextcloud user" : "عضو نكست كلاود",
-    "User password" : "كلمة مرور المستخدم",
-    "Talk conversation" : "محادثات",
-    "Team name" : "اسم الفريق",
-    "Channel name" : "اسم القناة",
-    "User name or e-mail address" : "اسم المستخدم او البريد الالكتروني",
-    "Password" : "الكلمة السرية",
-    "Server ID or name" : "معرف الخادم السحابي او الاسم",
-    "Channel ID or name" : "معرف القناة او الاسم",
-    "Chat ID" : "معرف المحادثة",
-    "Login" : "الدخول",
-    "Nickname" : "كنية.\nلقب.",
-    "Connection password" : "كلمة مرور الاتصال",
-    "Channel password" : "كلمة مرور القناة",
-    "Use TLS" : "استخدم TLS",
-    "Skip TLS verification" : "تجاهل تحقق من TLS",
-    "Tenant ID" : "معرف المستأجر",
-    "Client ID" : "معرف العميل",
-    "Team ID" : "معرف الفريق",
-    "Thread ID" : "معرف الموضوع",
-    "Channel" : "قناة",
-    "unknown state" : "حالة غير معروفة",
-    "running" : "فعال",
-    "not running" : "غير فعال",
     "moderator" : "مشرف",
     "guest" : "ضيف",
     "Demote from moderator" : "تخفيض رتبة مشرف",
@@ -536,7 +532,6 @@ OC.L10N.register(
     "An error occurred while fetching the participants" : "حدث خطأ اثناء اضافة مشاركيين",
     "Chat" : "الدردشة",
     "Display name: " : "اسم العرض:",
-    "Edit" : "تعديل",
     "Choose devices" : "اختر الاجهزة",
     "Attachments folder" : "مجلد المرفقات",
     "Keyboard shortcuts" : "إختصارات لوحة المفاتيح",
@@ -556,7 +551,6 @@ OC.L10N.register(
     "Start call" : "ابدء مكالمة",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "تم تحديث تطبيق نكست كلاود التحدث يرجى تحديث الصفحة قبل بدء مكالمة او الانضمام الى مكالمة.",
     "You will be able to join the call only after a moderator starts it." : "لن تتمكن من الانضمام إلى المكالمة إلا بعد أن يبدأها المشرف.",
-    "Use speaker view" : "استخدام عرض المتحدث",
     "Toggle fullscreen" : "تفعيل/تعطيل ملء الشاشة",
     "Go to file" : "الذهاب إلى ملف",
     "Rename conversation" : "إعادة تسمية المحادثة",
@@ -565,7 +559,6 @@ OC.L10N.register(
     "Fullscreen (f)" : "ملء الشاشة (f)",
     "Speaker view" : "عرض المتحدث",
     "Grid view" : "عرض كمخطط",
-    "Too many videos to fit in the window. Maximize the window or switch to \"speaker view\" for a better experience." : "الكثير من مقاطع الفيديو في النافذة. تكبير النافذة أو التبديل إلى \"عرض المتحدث\" للحصول على تجربة أفضل.",
     "Send" : "أرسل",
     "Add more files" : "اضافة المزيد من الملفات",
     "No unread mentions" : "لا يوجد منشن جديد",
@@ -577,11 +570,10 @@ OC.L10N.register(
     "Mention room" : "منشن غرفة",
     "The conversation does not exist" : "المحادثة غير موجودة",
     "Join a conversation or start a new one!" : "انضم لمحادثة او ابدء محادثة جديدة!",
-    "Link to a conversation" : "الربط لمحادثة",
     "Select conversation" : "اختر محادثة",
+    "Link to a conversation" : "الربط لمحادثة",
     "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "انضممت لمحادثة آخرى في نافذة او جهاز آخر. هذه الخاصية غير مدعومة سيتم اغلاق هذه الجلسة من قبل نكست كلاود التحدث.",
     "Join a conversation or start a new one" : "انضم لمحادثة او ابدء محادثة جديدة",
-    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "تستخدم متصفح غير مدعوم بالكامل من قبل نكست كلاود التحدث. استخدم اخر اصدار من فايرفوكس، مايكروسوفت ادج، قوقل كروم او ابل سفاري.",
     "Nextcloud Talk was updated, please reload the page" : "تم تحديث نكست كلاود التحدث، يرجى تحديث الصفحة.",
     "Do not disturb" : "عدم الازعاج",
     "Away" : "بالخارج",
@@ -591,7 +583,6 @@ OC.L10N.register(
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "انضممت لمحادثة آخرى في نافذة او جهاز آخر. هذه الخاصية غير مدعومة سيتم اغلاق هذه الجلسة من قبل نكست كلاود التحدث. ماذا تريد ان تفعل؟",
     "Join here" : "انضم لهذا",
     "Leave this page" : "مغادرة هذه الصفحة",
-    "Error while uploading file" : "خطأ اثناء رفع ملف",
     "Default" : "افتراضي",
     "Microphone {number}" : "مايك {number}",
     "Camera {number}" : "كاميرا {number}",
@@ -609,41 +600,24 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "انضم إلى المحادثات في أي وقت و من أي مكان و عبر أي جهاز",
     "Android app" : "تطبيق الأندرويد",
     "iOS app" : "تطبيق آي أواس",
+    "New in Talk 6" : "جديد التحدث 6",
+    "New in Talk 9" : "جديد التحدث نسخة 9",
     "{user} wants to talk with you" : "{user} يريد التحدث اليك",
-    "No other people in this call" : "لا يوجد اشخاص في هذه المكالمة",
-    "Your screen" : "شاشتك",
-    "Conversation, " : "محادثة،",
-    "Contacts" : "جهات الاتصال",
-    "Contacts, groups and circles" : "جهات الاتصال، المجموعات والجماعات",
-    "Contacts and groups" : "جهات الاتصال والمجموعات",
-    "Contacts and circles" : "جهات الاتصال والجماعات",
-    "Loading contacts" : "جاري تحميل جهات الاتصال",
-    "Select participants" : "اختر مشاركين",
-    "Search conversations or contacts" : "ابحث عن محادثات او جهات اتصال",
-    "[Unknown user name]" : "[اسم مستخدم غير معروف]",
-    "Participant settings" : "اعدادات المشاركين",
-    "Search for more contacts" : "البحث عن مزيد من جهات الاتصال",
-    "Contacts loading" : "جاري تحميل جهات الاتصال",
-    "Add participants to the conversation" : "اضافة مشاركين لهذه المحادثة",
-    "Add contacts" : "اضافة جهات اتصال",
-    "Add contacts, groups or circles" : "اضافة جهات اتصال، مجموعات او جماعات",
-    "Add contacts or groups" : "اضافة جهات اتصال او مجموعات",
-    "Add contacts or circles" : "اضف جهات اتصال او جماعات",
-    "Guests" : "الضيوف",
-    "Share link" : "مشاركة الرابط",
-    "Webinar" : "نقاش عبر الويب - ويب نير",
-    "Projects" : "المشاريع",
-    "Limit app usage to groups." : "تقييد استخدام التطبيق لمجموعات.",
-    "Start calls" : "ابدء مكالمات",
-    "Who can start a call?" : "من يمكنه بدء مكالمة؟",
-    "Select a conversation to add to the project" : "اختر محادثة لاضافتها إلى المشروع.",
-    "Please enter the password for this call" : "أدخل كلمة المرور لهذه المكالمة",
-    "Password required" : "كلمة السر مطلوبة",
-    "Cancel" : "إلغاء",
-    "Submit" : "ارسال",
     "This conversation is read only" : "هذه المحادثة للقراءة فقط",
+    "Conversation, " : "محادثة،",
     "Default location for attachments" : "مكان المرفقات الافتراضي",
     "Select default location for attachments" : "اختر مكان المرفقات الافتراضي",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call" : "تم تحديث تطبيق نكست كلاود التحدث يرجى تحديث الصفحة قبل بدء مكالمة او الانضمام الى مكالمة."
+    "Participant settings" : "اعدادات المشاركين",
+    "Add participants to the conversation" : "اضافة مشاركين لهذه المحادثة",
+    "Projects" : "المشاريع",
+    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call" : "تم تحديث تطبيق نكست كلاود التحدث يرجى تحديث الصفحة قبل بدء مكالمة او الانضمام الى مكالمة.",
+    "Use speaker view" : "استخدام عرض المتحدث",
+    "Share link" : "مشاركة الرابط",
+    "Too many videos to fit in the window. Maximize the window or switch to \"speaker view\" for a better experience." : "الكثير من مقاطع الفيديو في النافذة. تكبير النافذة أو التبديل إلى \"عرض المتحدث\" للحصول على تجربة أفضل.",
+    "Select a conversation to add to the project" : "اختر محادثة لاضافتها إلى المشروع.",
+    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "تستخدم متصفح غير مدعوم بالكامل من قبل نكست كلاود التحدث. استخدم اخر اصدار من فايرفوكس، مايكروسوفت ادج، قوقل كروم او ابل سفاري.",
+    "Error while uploading file" : "خطأ اثناء رفع ملف",
+    "Bridge with other services" : "الربط مع خدمات آخرى",
+    "Enabled" : "مفعلة"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
