@@ -15,21 +15,17 @@ OC.L10N.register(
     "Talk" : "Komz",
     "Guest" : "Kouviad",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Donemat war Nextcloud Talk !\nEn diviz-mañ e voc'h kemenet diwar-benn perzhioù nevez a kavoc'h e Nextcloud Talk.",
-    "New in Talk 6" : "Nevez e Talk 6",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Micosoft Edge ha Safari a zo posupl implij evit ar gemenadenoù audio a video",
     "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- N'eo ket posupl lakaat un diviz unan-hag-unan en un diviz a stroll dre fazi kenn. Pa vez laosket an diviz gant una bennak, n'eo ket lemet an diviz en un doare otomatek kenn. N'eo lemet an diviz eus ar servijour nemet ma vez laosket gant tout an dud.",
     "- You can now notify all participants by posting \"@all\" into the chat" : "- Posupl eo deoc'h gervel tout en dud en diviz en ur skrivañ \"@all\" er chat",
     "- With the \"arrow-up\" key you can repost your last message" : " -Gant an douchenn \"bir-a-uz\" en posupl adkas ar gemenadenn divezhañ",
     "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk en deus urzioù bremañ, kasit \"/help\" evel ur gemenadenn chat evit gwelet m'az eo bet stummet urzioù gant o merour",
     "- With projects you can create quick links between conversations, files and other items" : "- Gant Raktres eo posupl deoc'h krouiñ liammoù etre an divizoù, restroù ha traoù all",
-    "New in Talk 7" : "Nevez e Talk 7",
     "- You can now mention guests in the chat" : "- Posuple eo deoc'h menegiñ kouvidi er chat",
     "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Ur sal gortoz eo posupl kaout evit an divizoù. Aotreañ a raio an habaskaerien da vont er chat hag er gemenaden evit prientiñ ar gejadenn, padal eo ret d'an implijourien ha d'ar gouviidi gortoz",
-    "New in Talk 8" : "Nevez e Talk 8",
     "- You can now directly reply to messages giving the other users more context what your message is about" : "- Posupl eo deoc'h respont diouzhtu d'ar gemenadennoù en ur displegañ diwar benn petra eo ar gemenadenn.",
     "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Klask divizoù ha lodeget a implijo ivez ho divizoù, ma vo aesoc'h adkavout divizoù kozh",
     "- You can now add custom user groups to conversations when the circles app is installed" : "- Posupl eo deoc'h ouzhpenañ strolladoù implijourien personelaet d'an divizoù gant ar meziant kelc'h staliet",
-    "New in Talk 9" : "Nevez e Talk 9",
     "- Check out the new grid and call view" : "- Sellit ouzh ar rouedad ha kemener nevez",
     "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Posuple eo deoc'h pelkas ha ruzañ-lakaat restroù diozhtu eus o ardivink er chat",
     "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Restrom rannet a vez igoret diozhtu er chat gant ar lenner maziant",
@@ -532,9 +528,6 @@ OC.L10N.register(
     "TURN server URL" : "URL ar servijour TURN",
     "TURN server secret" : "Servijour TURN sekret",
     "TURN server protocols" : "Protokoloù servijour TURN",
-    "UDP and TCP" : "UDP ha TCP",
-    "UDP only" : "UDP nemetken",
-    "TCP only" : "TCP nemetken",
     "OK: Successful ICE candidates returned by the TURN server" : "OK : ICE emstriver mat edkaset gant ar servijour TURN",
     "Error: No working ICE candidates returned by the TURN server" : "Fazi : Ne labour ket ICE emstriver adkaset gant ar servijour TURN",
     "Testing whether the TURN server returns ICE candidates" : "Amprouiñ adkasadenn emstriver ICE at servijour TURN",
@@ -551,6 +544,7 @@ OC.L10N.register(
     "Share a single window" : "Rannañ ur prenestr nemetken",
     "Show your screen" : "Diskouez ar skramm",
     "Stop screensharing" : "Echuañ ar rannadenn skramm",
+    "Settings" : "Arventennoù",
     "Dismiss" : "Arrest",
     "No audio" : "Audio ebet",
     "Mute audio (m)" : "Lac'hañ a audio (m)",
@@ -603,8 +597,14 @@ OC.L10N.register(
     "Conversation settings" : "Stummoù diviz",
     "Password protection" : "Gwareziñ gant ur ger-tremen",
     "Enter a password" : "Ebarzhiñ ar ger-tremen",
+    "Copy conversation link" : "Eilañ al liamm diviz",
     "Enable lobby" : "Aotreañ ar sal gortoz",
     "Start time (optional)" : "Amzer kregiñ (dibab)",
+    "Save" : "Enrollañ",
+    "Edit" : "Cheñch",
+    "Password" : "Ger-tremen",
+    "Login" : "Anv arveriad",
+    "Client ID" : "ID kliant",
     "Chat notifications" : "Kemenadennoù chat",
     "Leave conversation" : "Kuitaat an diviz",
     "Delete conversation" : "Lemel an diviz",
@@ -619,15 +619,14 @@ OC.L10N.register(
     "No search results" : "Disoc'h enklask ebet",
     "Groups" : "Strolladoù",
     "Circles" : "Kelc'hioù",
-    "Settings" : "Arventennoù",
     "Users, groups and circles" : "Implijouirinn, stroladoù ha kelc'hioù.",
     "Users and groups" : "Implijourienn ha strolladoù",
     "Users and circles" : "Implijourien ha kelc'hioù",
     "Groups and circles" : "Strolladoù ha kelc'hioù",
     "Other sources" : "Orin all",
+    "An error occurred while performing the search" : "Ur fazi a zo bet en ur ober an enklask",
     "Creating your conversation" : "Krouiñ ho diviz",
     "All set" : "Staliet pep tra",
-    "Copy conversation link" : "Eilañ al liamm diviz",
     "Error while creating the conversation" : "Ur fazi a zo bet en ur krouiñ an diviz",
     "Link copied to the clipboard!" : "Liamm eilet d'ar golver",
     "Create a new group conversation" : "Krouiñ un diviz strollad nevez",
@@ -637,7 +636,6 @@ OC.L10N.register(
     "Close" : "Serriñ",
     "Choose a password" : "Choaz ur get-trmenn",
     "Search participants" : "Klask implijer",
-    "An error occurred while performing the search" : "Ur fazi a zo bet en ur ober an enklask",
     "Conversation name" : "Anv diviz",
     "Allow guests to join via link " : "Aotreaén ar c'houvidi da don dre liamm",
     "Search conversations or users" : "Klask divizoù ha implijourienn",
@@ -668,11 +666,6 @@ OC.L10N.register(
     "File to share" : "Restr da rannañ",
     "Write message, @ to mention someone …" : "Skrivañ ur gemenadenn, @ evit menegiñ unan bennak ...",
     "Invalid path selected" : "An hent dibabet n'eus ket anezhañ",
-    "Enabled" : "Aotreet",
-    "Save" : "Enrollañ",
-    "Password" : "Ger-tremen",
-    "Login" : "Anv arveriad",
-    "Client ID" : "ID kliant",
     "moderator" : "habaskaer",
     "guest" : "kouviad",
     "Demote from moderator" : "Lemel eus ar moderatourienn",
@@ -694,7 +687,6 @@ OC.L10N.register(
     "An error occurred while fetching the participants" : "Ur fazi a zo bet en ur pakañ an tud",
     "Chat" : "Chat",
     "Display name: " : "Anv tra :",
-    "Edit" : "Cheñch",
     "Choose devices" : "Choazit un ardivink",
     "Attachments folder" : "Teuliad stag",
     "Search" : "Klask",
@@ -721,11 +713,10 @@ OC.L10N.register(
     "Mention room" : "Sal meneg",
     "The conversation does not exist" : "N'ez eus ket eus an diviz-mañ",
     "Join a conversation or start a new one!" : "Mont en un diviz pe kregiñ unan nevez !",
-    "Link to a conversation" : "Liamm d'an diviz",
     "Select conversation" : "Choaz un diviz",
+    "Link to a conversation" : "Liamm d'an diviz",
     "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Deuet oc'h en diviz dre ur prenestr pe ardivink all. N'eo ket douget evit ar poent gant Nextcloud Talk neuze eo bet sertet an dalc'h.",
     "Join a conversation or start a new one" : "Mont en un diviz pe kregiñ unan nevez ",
-    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "N'eo ket douget pen-da-benn ho furcher gant Nextcloud Talk. Implijit kentec'h stum divezhañ Mozilla Firefox, Microsoft Edge, Google Chrome pe Apple Safari.",
     "Nextcloud Talk was updated, please reload the page" : "Adnevesaet eo bet Nextcloud Talk , adkargit ar bajenn",
     "Do not disturb" : "Na rannit ket",
     "Away" : "Pell",
@@ -735,7 +726,6 @@ OC.L10N.register(
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Ho klask mont en diviz emaoc'h p'ho peus un dalc'h en ur prenestr pe ardivink all. N'eo ket douget c'hoaz gant Nextcloud Talk. Petra o peus c'hoant ober ?",
     "Join here" : "Kejañ amañ",
     "Leave this page" : "Kuitaat ar bajenn",
-    "Error while uploading file" : "Ur fazi a zo bet en ur pellkas ar restr",
     "Sending signaling message has failed." : "Kasadenn ar gemenadenn arhentañ a zo c'hwitet.",
     "Lost connection to signaling server. Trying to reconnect." : "Kenstagadenn gant ar servijour arhent kollet. O klask adkemprenn.",
     "Lost connection to signaling server. Try to reload the page manually." : "Kenstagadenn gant ar servijour arhent kollet. Klaskit adkemprenn gant an dorn.",
@@ -765,42 +755,27 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Kit en diviz n'eus forzh peseurt amzer, lec'h pe ardivink.",
     "Android app" : "Meziant Android",
     "iOS app" : "Meziant iOS",
+    "New in Talk 6" : "Nevez e Talk 6",
+    "New in Talk 7" : "Nevez e Talk 7",
+    "New in Talk 8" : "Nevez e Talk 8",
+    "New in Talk 9" : "Nevez e Talk 9",
     "{user} wants to talk with you" : "{user} en dus c'hoant da gomz deoc'h",
-    "No other people in this call" : "Denn ebet all er gemenadenn",
-    "Your screen" : "Ho skramm",
-    "Conversation, " : "Diviz,",
-    "Contacts" : "Darempredoù",
-    "Contacts, groups and circles" : "Darempredoùn, strolladoù ha kelc'hioù",
-    "Contacts and groups" : "Darempredoù ha strolladoù",
-    "Contacts and circles" : "Darempredoù ha kelc'hioù",
-    "Loading contacts" : "HO kargañ an darempredoù",
-    "Select participants" : "Choaz unan bennak",
-    "Search conversations or contacts" : "Klask un diviz pe un darempred",
-    "[Unknown user name]" : "[Anv implijer dianv]",
-    "Participant settings" : "Arventennoù tud",
-    "Search for more contacts" : "Klask muioc'h ha darempredoù",
-    "Contacts loading" : "Darempredoù o kargañ",
-    "Add participants to the conversation" : "Ouzhpennañ tud en diviz",
-    "Add contacts" : "Ouzhpennañ darempredoù",
-    "Add contacts, groups or circles" : "Ouzhpennañ darempredoù, strolladoù pe kelc'hioù",
-    "Add contacts or groups" : "Ouzphennañ darempredoù pe strolladoù",
-    "Add contacts or circles" : "Ouzhpennañ darempredoù pe kelc'hioù",
-    "Guests" : "Kouviidi",
-    "Share link" : "Rannan liamm",
-    "Webinar" : "Bebinar",
-    "Projects" : "Raktres",
-    "Limit app usage to groups." : "Bevenna implij ar meziant da strolladoù.",
-    "Start calls" : "Kregiñ ur gemenadenn",
-    "Who can start a call?" : "Piv a c'hell kregiñ ur gemenadenn ?",
-    "Select a conversation to add to the project" : "Choaz un diviz da ouzhpennañ er raktres",
-    "Please enter the password for this call" : "Lakit ur ger-temenn evit ar gemenadenn-mañ",
-    "Password required" : "Ger-tremen ret",
-    "Cancel" : "Arrest",
-    "Submit" : "Kinnig",
     "Signaling server URL" : "O arhentañ URL ar servijour",
+    "UDP and TCP" : "UDP ha TCP",
+    "UDP only" : "UDP nemetken",
+    "TCP only" : "TCP nemetken",
     "This conversation is read only" : "An diviz a zo da lenn-nemetken",
+    "Conversation, " : "Diviz,",
     "Default location for attachments" : "Lec'h dre ziouer evit ar stagadennoù",
     "Select default location for attachments" : "Choaz al lec'h stagadenn dre ziouer",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call" : "Nextcloud Talk a zo bet adnevesaet, ret eo deoc'h freskaat ar bajenn a raok kregin pe mont en ur gemenadenn"
+    "Participant settings" : "Arventennoù tud",
+    "Add participants to the conversation" : "Ouzhpennañ tud en diviz",
+    "Projects" : "Raktres",
+    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call" : "Nextcloud Talk a zo bet adnevesaet, ret eo deoc'h freskaat ar bajenn a raok kregin pe mont en ur gemenadenn",
+    "Share link" : "Rannan liamm",
+    "Select a conversation to add to the project" : "Choaz un diviz da ouzhpennañ er raktres",
+    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "N'eo ket douget pen-da-benn ho furcher gant Nextcloud Talk. Implijit kentec'h stum divezhañ Mozilla Firefox, Microsoft Edge, Google Chrome pe Apple Safari.",
+    "Error while uploading file" : "Ur fazi a zo bet en ur pellkas ar restr",
+    "Enabled" : "Aotreet"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
