@@ -15,17 +15,14 @@ OC.L10N.register(
     "Talk" : "Snak",
     "Guest" : "Gæst",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Velkommen til Nextcloud Talk!\nI denne samtale finder du information om nye features tilgængelige i Nextcloud Talk.",
-    "New in Talk 6" : "Nyt i Talk 6",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge og Safari kan nu benyttes til at deltage i lyd- og videosamtaler",
     "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- En-til-en-samtaler er nu vedvarende og kan ikke laves til gruppesamtaler ved en fejl længere. Derudover bliver samtaler ikke længere slettet automatisk når en af deltagerne forlader den. Samtalen slettes kun fra serveren hvis begge deltagere har forladt den",
     "- You can now notify all participants by posting \"@all\" into the chat" : "- Nu kan nu sende en notifikation til alle deltagere ved at skrive \"@all\" i chatten",
     "- With the \"arrow-up\" key you can repost your last message" : "- Ved at trykke på \"pil op\" kan du sende din sidste besked igen",
     "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk understøtter nu kommandoer. Send \"/help\" som en chat-besked for at se om din administrator har konfigureret nogen",
     "- With projects you can create quick links between conversations, files and other items" : "- Med projekter kan du oprette hurtige links mellem samtaler, filer og andre objekter",
-    "New in Talk 7" : "Nyt i Talk 7",
     "- You can now mention guests in the chat" : "- Du kan nu nævne gæster i samtalen",
     "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Samtaler kan nu have en lobby. Dette giver mulighed for at moderatorer kan forbinde til samtalen for at forberede mødet, mens almindelige brugere og gæster må vente",
-    "New in Talk 8" : "Nyt i Talk 8",
     "- You can now directly reply to messages giving the other users more context what your message is about" : "- Du kan nu svare direkte på beskeder og dermed give andre brugere mere kontekst om hvad din besked handler om",
     "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Søgninger efter samtaler og deltagere vil nu også filtrere dine eksisterende samtaler, hvilke gør det meget nemmere at finde tidligere samtaler",
     "- You can now add custom user groups to conversations when the circles app is installed" : "- Du kan nu tilføje brugerdefinerede brugergrupper til samtaler når cirkel-appen er installeret",
@@ -280,9 +277,6 @@ OC.L10N.register(
     "TURN server URL" : "TURN server URL",
     "TURN server secret" : "TURN-server secret",
     "TURN server protocols" : "TURN server protokoller ",
-    "UDP and TCP" : "UDP og TCP",
-    "UDP only" : "kun UDP",
-    "TCP only" : "kun TCP",
     "Test this server" : "Test denne server",
     "TURN servers" : "TURN-servere",
     "Copy link" : "Kopier link",
@@ -296,6 +290,7 @@ OC.L10N.register(
     "Share a single window" : "Del et vindue",
     "Show your screen" : "Vis din skærm",
     "Stop screensharing" : "Stop skærmdeling",
+    "Settings" : "Indstillinger",
     "Dismiss" : "Afvis",
     "No audio" : "Ingen lyd",
     "Mute audio (m)" : "Slå lyden fra (m)",
@@ -327,8 +322,16 @@ OC.L10N.register(
     "Favorite" : "Foretrukken",
     "Password protection" : "Adgangskodebeskyttelse",
     "Enter a password" : "Enter a password",
+    "Copy conversation link" : "Kopier samtalelink",
     "Enable lobby" : "Aktiver lobby",
     "Start time (optional)" : "Starttid (valgfri)",
+    "Save" : "Gem",
+    "Edit" : "Rediger",
+    "Password" : "Password",
+    "API token" : "API nøgle",
+    "Login" : "Login",
+    "Nickname" : "Kaldenavn",
+    "Client ID" : "Klient-ID",
     "Chat notifications" : "Chat-notifikationer",
     "Leave conversation" : "Forlad samtale",
     "Delete conversation" : "Slet samtale",
@@ -343,12 +346,11 @@ OC.L10N.register(
     "No search results" : "Ingen søgeresultater",
     "Groups" : "Grupper",
     "Circles" : "Cirkler",
-    "Settings" : "Indstillinger",
     "Groups and circles" : "Grupper og cirkler",
     "Other sources" : "Andre kilder",
+    "An error occurred while performing the search" : "Der opstod en fejl under søgningen",
     "Creating your conversation" : "Opret din samtale",
     "All set" : "Samtalen er klar",
-    "Copy conversation link" : "Kopier samtalelink",
     "Error while creating the conversation" : "Fejl under oprettelse af samtalen",
     "Link copied to the clipboard!" : "Link kopieret til udklipsholderen!",
     "Create a new group conversation" : "Opret en ny gruppesamtale",
@@ -358,7 +360,6 @@ OC.L10N.register(
     "Close" : "Luk",
     "Choose a password" : "Vælg en adgangskode",
     "Search participants" : "Find deltagere",
-    "An error occurred while performing the search" : "Der opstod en fejl under søgningen",
     "Conversation name" : "Samtalenavn",
     "Allow guests to join via link " : "Tillad gæster at deltage via link",
     "You are currently waiting in the lobby" : "Du venter nu i lobbyen",
@@ -376,13 +377,6 @@ OC.L10N.register(
     "File to share" : "Vælg fil til deling",
     "Write message, @ to mention someone …" : "Skriv besked, brug @ for at nævne en bruger ...",
     "Invalid path selected" : "Ugyldig filsti valgt",
-    "Enabled" : "Aktiveret",
-    "Save" : "Gem",
-    "Password" : "Password",
-    "API token" : "API nøgle",
-    "Login" : "Login",
-    "Nickname" : "Kaldenavn",
-    "Client ID" : "Klient-ID",
     "moderator" : "moderator",
     "guest" : "Gæst",
     "Demote from moderator" : "Degrader fra moderator",
@@ -400,7 +394,6 @@ OC.L10N.register(
     "An error occurred while fetching the participants" : "Kunne ikke hente listen over deltagere",
     "Chat" : "Chat",
     "Display name: " : "Vist navn:",
-    "Edit" : "Rediger",
     "Keyboard shortcuts" : "Tastaturgenveje",
     "Search" : "Søg",
     "Error while setting attachment folder" : "Fejl under indstilling af mappe til vedhæftninger",
@@ -418,11 +411,10 @@ OC.L10N.register(
     "Mention room" : "Nævn rum",
     "The conversation does not exist" : "Samtalen findes ikke",
     "Join a conversation or start a new one!" : "Deltag i en samtale eller start en ny!",
-    "Link to a conversation" : "Link til samtale",
     "Select conversation" : "Vælg samtale",
+    "Link to a conversation" : "Link til samtale",
     "Join a conversation or start a new one" : "Deltag i en samtale eller start en ny",
     "Error while sharing file" : "Fejl ved deling af fil",
-    "Error while uploading file" : "Fejl ved upload af fil",
     "Sending signaling message has failed." : "Kunne ikke sende signalerings-besked",
     "Default" : "Standard",
     "You seem to be talking while muted, please unmute yourself for others to hear you" : "Det virker som om du snakker mens lyden er slået fra, slå den til hvis du vil have at andre skal høre dig",
@@ -444,39 +436,22 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Deltag i samtaler når som helst, hvor som helst og på en hvilken som helst enhed.",
     "Android app" : "Android app",
     "iOS app" : "iOS app",
+    "New in Talk 6" : "Nyt i Talk 6",
+    "New in Talk 7" : "Nyt i Talk 7",
+    "New in Talk 8" : "Nyt i Talk 8",
     "{user} wants to talk with you" : "{user} vil gerne snakke med dig",
-    "No other people in this call" : "Ingen andre deltager i dette opkald",
-    "Your screen" : "Din skærm",
-    "Contacts" : "Kontakter",
-    "Contacts, groups and circles" : "Kontakter, grupper og cirkler",
-    "Contacts and groups" : "Kontakter og grupper",
-    "Contacts and circles" : "Kontakter og cirkler",
-    "Loading contacts" : "Henter kontakter",
-    "Select participants" : "Vælg deltagere",
-    "Search conversations or contacts" : "Søg efter samtaler og kontakter",
-    "[Unknown user name]" : "[Ukendt brugernavn] ",
-    "Search for more contacts" : "Søg efter flere kontakter",
-    "Contacts loading" : "Henter kontakter",
-    "Add participants to the conversation" : "Tilføj deltagere til samtalen",
-    "Add contacts" : "Tilføj kontakter",
-    "Add contacts, groups or circles" : "Tilføj kontakter, grupper eller cirkler",
-    "Add contacts or groups" : "Tilføj kontakter eller grupper",
-    "Add contacts or circles" : "Tilføj kontakter eller cirkler",
-    "Guests" : "Gæster",
-    "Share link" : "Del link",
-    "Webinar" : "Webinar",
-    "Projects" : "Projekter",
-    "Limit app usage to groups." : "Begræns app-brug til grupper.",
-    "Start calls" : "Start opkald",
-    "Who can start a call?" : "Hvem kan starte et opkald?",
-    "Select a conversation to add to the project" : "Vælg en samtale for at tilføje den til projektet",
-    "Please enter the password for this call" : "Indtast venligst password for dette opkald",
-    "Password required" : "Password påkrævet",
-    "Cancel" : "Annullér",
-    "Submit" : "Indsend",
     "Signaling server URL" : "Signalserver URL",
+    "UDP and TCP" : "UDP og TCP",
+    "UDP only" : "kun UDP",
+    "TCP only" : "kun TCP",
     "This conversation is read only" : "Denne samtale er skrivebeskyttet",
     "Default location for attachments" : "Standard-lokation for vedhæftninger",
-    "Select default location for attachments" : "Vælg standard-lokation for vedhæftninger"
+    "Select default location for attachments" : "Vælg standard-lokation for vedhæftninger",
+    "Add participants to the conversation" : "Tilføj deltagere til samtalen",
+    "Projects" : "Projekter",
+    "Share link" : "Del link",
+    "Select a conversation to add to the project" : "Vælg en samtale for at tilføje den til projektet",
+    "Error while uploading file" : "Fejl ved upload af fil",
+    "Enabled" : "Aktiveret"
 },
 "nplurals=2; plural=(n != 1);");
