@@ -14,29 +14,23 @@ OC.L10N.register(
     "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>",
     "Talk" : "Talk",
     "Guest" : "Guest",
-    "- Spice up your messages with emojis from the emoji picker" : "- Spice up your messages with emojis from the emoji picker",
-    "- Spice up your messages with emojis from the emoji picker {emoji}" : "- Spice up your messages with emojis from the emoji picker {emoji}",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk.",
-    "New in Talk 6" : "New in Talk 6",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge and Safari can now be used to participate in audio and video calls",
     "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- One-to-one conversations are now persistent and can not be turned into group conversations by accident any more. Also when one of the participants leaves the conversation, the conversation is not automatically deleted any more. Only if both participants leave, the conversation is deleted from the server",
     "- You can now notify all participants by posting \"@all\" into the chat" : "- You can now notify all participants by posting \"@all\" into the chat",
     "- With the \"arrow-up\" key you can repost your last message" : "- With the \"arrow-up\" key you can repost your last message",
     "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some",
     "- With projects you can create quick links between conversations, files and other items" : "- With projects you can create quick links between conversations, files and other items",
-    "New in Talk 7" : "New in Talk 7",
     "- You can now mention guests in the chat" : "- You can now mention guests in the chat",
     "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait",
-    "New in Talk 8" : "New in Talk 8",
     "- You can now directly reply to messages giving the other users more context what your message is about" : "- You can now directly reply to messages giving the other users more context what your message is about",
     "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations",
     "- You can now add custom user groups to conversations when the circles app is installed" : "- You can now add custom user groups to conversations when the circles app is installed",
-    "New in Talk 9" : "New in Talk 9",
     "- Check out the new grid and call view" : "- Check out the new grid and call view",
     "- You can now upload and drag'n'drop files directly from your device into the chat" : "- You can now upload and drag'n'drop files directly from your device into the chat",
     "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Shared files are now opened directly inside the chat view with the viewer apps",
-    "New in Talk 10" : "New in Talk 10",
     "- You can now search for chats and messages in the unified search in the top bar" : "- You can now search for chats and messages in the unified search in the top bar",
+    "- Spice up your messages with emojis from the emoji picker" : "- Spice up your messages with emojis from the emoji picker",
     "- You can now change your camera and microphone while being in a call" : "- You can now change your camera and microphone while being in a call",
     "There are currently no commands available." : "There are currently no commands available.",
     "The command does not exist" : "The command does not exist",
@@ -83,9 +77,6 @@ OC.L10N.register(
     "STUN servers" : "STUN servers",
     "A STUN server is used to determine the public IP address of participants behind a router." : "A STUN server is used to determine the public IP address of participants behind a router.",
     "TURN server protocols" : "TURN server protocols",
-    "UDP and TCP" : "UDP and TCP",
-    "UDP only" : "UDP only",
-    "TCP only" : "TCP only",
     "Copy link" : "Copy link",
     "Waiting for others to join the call …" : "Waiting for others to join the call …",
     "You can invite others in the participant tab of the sidebar" : "You can invite others in the participant tab of the sidebar",
@@ -93,6 +84,7 @@ OC.L10N.register(
     "Share this link to invite others!" : "Share this link to invite others!",
     "Show your screen" : "Show your screen",
     "Stop screensharing" : "Stop screensharing",
+    "Settings" : "Settings",
     "Dismiss" : "Dismiss",
     "No audio" : "No audio",
     "Mute audio (m)" : "Mute audio (m)",
@@ -115,6 +107,13 @@ OC.L10N.register(
     "Favorite" : "Favourite",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
+    "Save" : "Save",
+    "Edit" : "Edit",
+    "Password" : "Password",
+    "API token" : "API token",
+    "Login" : "Login",
+    "Nickname" : "Nickname",
+    "Client ID" : "Client ID",
     "Leave conversation" : "Leave conversation",
     "Delete conversation" : "Delete conversation",
     "Remove from favorites" : "Remove from favourites",
@@ -122,7 +121,6 @@ OC.L10N.register(
     "Loading" : "Loading",
     "Groups" : "Groups",
     "Circles" : "Circles",
-    "Settings" : "Settings",
     "Password protect" : "Password protect",
     "Close" : "Close",
     "Conversation name" : "Conversation name",
@@ -133,13 +131,6 @@ OC.L10N.register(
     "Yesterday" : "Yesterday",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Send message" : "Send message",
-    "Enabled" : "Enabled",
-    "Save" : "Save",
-    "Password" : "Password",
-    "API token" : "API token",
-    "Login" : "Login",
-    "Nickname" : "Nickname",
-    "Client ID" : "Client ID",
     "moderator" : "moderator",
     "guest" : "guest",
     "Demote from moderator" : "Demote from moderator",
@@ -149,7 +140,6 @@ OC.L10N.register(
     "Add users or groups" : "Add users or groups",
     "Participants" : "Participants",
     "Chat" : "Chat",
-    "Edit" : "Edit",
     "Keyboard shortcuts" : "Keyboard shortcuts",
     "Search" : "Search",
     "Rename conversation" : "Rename conversation",
@@ -173,17 +163,16 @@ OC.L10N.register(
     "%s Talk on your mobile devices" : "%s Talk on your mobile devices",
     "Android app" : "Android app",
     "iOS app" : "iOS app",
+    "New in Talk 6" : "New in Talk 6",
+    "New in Talk 7" : "New in Talk 7",
+    "New in Talk 8" : "New in Talk 8",
+    "New in Talk 9" : "New in Talk 9",
     "{user} wants to talk with you" : "{user} wants to talk with you",
-    "No other people in this call" : "No other people in this call",
-    "Your screen" : "Your screen",
-    "Contacts" : "Contacts",
-    "[Unknown user name]" : "[Unknown user name]",
-    "Guests" : "Guests",
+    "UDP and TCP" : "UDP and TCP",
+    "UDP only" : "UDP only",
+    "TCP only" : "TCP only",
     "Share link" : "Share link",
-    "Limit app usage to groups." : "Limit app usage to groups.",
-    "Please enter the password for this call" : "Please enter the password for this call",
-    "Password required" : "Password required",
-    "Cancel" : "Cancel",
-    "Submit" : "Submit"
+    "New in Talk 10" : "New in Talk 10",
+    "Enabled" : "Enabled"
 },
 "nplurals=2; plural=(n != 1);");
