@@ -21,7 +21,6 @@ OC.L10N.register(
     "- With the \"arrow-up\" key you can repost your last message" : "- Puedes reenviar tu último mensaje con la tecla \"flecha arriba\"",
     "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk ahora puede recibir comandos, envia \"/help\" como mensaje en el chat para ver si tu administrador configuro algunos",
     "- With projects you can create quick links between conversations, files and other items" : "- Con projects puedes crear ligas entre conversaciones, archivos y otros artículos.",
-    "New in Talk 7" : "Nuevo en Talk 7",
     "- You can now mention guests in the chat" : "- Ahora puedes mencionar a invitados en el chat",
     "There are currently no commands available." : "No hay comandos disponibles actualmente",
     "The command does not exist" : "El comando no existe",
@@ -123,9 +122,6 @@ OC.L10N.register(
     "STUN servers" : "Servidores STUN",
     "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
     "TURN server protocols" : "Protocolos del servidor TURN",
-    "UDP and TCP" : "UDP y TCP",
-    "UDP only" : "UDP únicamente",
-    "TCP only" : "TCP únicamente",
     "Copy link" : "Copiar liga",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
@@ -133,6 +129,7 @@ OC.L10N.register(
     "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
     "Show your screen" : "Mostrar tu pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
+    "Settings" : "Configuraciones ",
     "Dismiss" : "Descartar",
     "No audio" : "Sin audio",
     "Mute audio (m)" : "Silenciar audio (m)",
@@ -155,6 +152,13 @@ OC.L10N.register(
     "Favorite" : "Hacer favorito",
     "Password protection" : "Protección con contraseña",
     "Enter a password" : "Ingresa una contraseña",
+    "Save" : "Guardar",
+    "Edit" : "Editar",
+    "Password" : "Contraseña",
+    "API token" : "Ficha del API",
+    "Login" : "Iniciar sesión",
+    "Nickname" : "Apodo",
+    "Client ID" : "ID del cliente",
     "Leave conversation" : "Dejar la conversación",
     "Delete conversation" : "Borrar conversación",
     "Remove from favorites" : "Eliminar de favoritos",
@@ -162,7 +166,6 @@ OC.L10N.register(
     "Loading" : "Cargando",
     "Groups" : "Grupos",
     "Circles" : "Círculos",
-    "Settings" : "Configuraciones ",
     "Password protect" : "Proteger con contraseña",
     "Close" : "Cerrar",
     "Conversation name" : "Nombre de la conversación",
@@ -171,13 +174,6 @@ OC.L10N.register(
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Enabled" : "Habilitado",
-    "Save" : "Guardar",
-    "Password" : "Contraseña",
-    "API token" : "Ficha del API",
-    "Login" : "Iniciar sesión",
-    "Nickname" : "Apodo",
-    "Client ID" : "ID del cliente",
     "moderator" : "moderador",
     "guest" : "invitado",
     "Demote from moderator" : "Degradar de moderador",
@@ -187,7 +183,6 @@ OC.L10N.register(
     "Add users or groups" : "Agregar usuarios o grupos",
     "Participants" : "Participantes",
     "Chat" : "Chat",
-    "Edit" : "Editar",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Search" : "Buscar",
     "Rename conversation" : "Renombrar conversación",
@@ -210,16 +205,12 @@ OC.L10N.register(
     "%s Talk on your mobile devices" : "%s Habla en tus dispositivos móviles",
     "Android app" : "Aplicación Android",
     "iOS app" : "Aplicación iOS",
+    "New in Talk 7" : "Nuevo en Talk 7",
     "{user} wants to talk with you" : "{user} quiere hablar contigo",
-    "No other people in this call" : "No hay más personas en esta llamada",
-    "Your screen" : "Tu pantalla",
-    "Contacts" : "Contactos",
-    "[Unknown user name]" : "[Nombre de usuario desconocido]",
-    "Guests" : "Invitados",
+    "UDP and TCP" : "UDP y TCP",
+    "UDP only" : "UDP únicamente",
+    "TCP only" : "TCP únicamente",
     "Share link" : "Compartir liga",
-    "Please enter the password for this call" : "Por favor ingresa la contraseña para esta llamada",
-    "Password required" : "Contraseña requerida",
-    "Cancel" : "Cancelar",
-    "Submit" : "Enviar"
+    "Enabled" : "Habilitado"
 },
 "nplurals=2; plural=(n != 1);");
