@@ -15,14 +15,12 @@ OC.L10N.register(
     "Talk" : "گفتگو",
     "Guest" : "مهمان",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "به بحث نکست کلود خوش آمدید!\nدر این گفتگو از ویژگی های جدید موجود در نکست کلودTalk مطلع می شوید.",
-    "New in Talk 6" : "جدید در Talk 6",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "اکنون می توان از Microsoft Edge و Safari برای شرکت در تماس های صوتی و تصویری استفاده کرد",
     "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- مکالمات یک به یک هم اکنون برقرار است و دیگر نمی توان به طور تصادفی به مکالمه های گروهی تبدیل کرد. همچنین وقتی یکی از شرکت کنندگان مکالمه را ترک می کند ، مکالمه دیگر به طور خودکار حذف نمی شود. فقط در صورت ترک هر دو شرکت کننده ، مکالمه از سرور حذف می شود",
     "- You can now notify all participants by posting \"@all\" into the chat" : "- اکنون می توانید با ارسال \"@all\" در گپ ، به همه شرکت کنندگان اطلاع دهید",
     "- With the \"arrow-up\" key you can repost your last message" : "- با کلید \"جهت بالا\" می توانید آخرین پیام خود را دوباره ارسال کنید",
     "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- - بحث اکنون می تواند دستوراتی داشته باشد ، \"/ help\" را به عنوان یک پیام چت ارسال کنید تا ببینید سرپرست شما برخی از آنها را پیکربندی کرده است یا خیر",
     "- With projects you can create quick links between conversations, files and other items" : "- با پروژه ها می توانید پیوندهای سریع بین مکالمات ، پرونده ها و موارد دیگر ایجاد کنید",
-    "New in Talk 7" : "جدید در Talk 7",
     "- You can now mention guests in the chat" : "- اکنون می توانید از مهمان ها در چت یاد کنید",
     "There are currently no commands available." : "در حال حاضر هیچ  فرمانی موجود نیست.",
     "The command does not exist" : "هیچ فرمان وجود ندارد",
@@ -266,6 +264,7 @@ OC.L10N.register(
     "Copy link" : "کپی کردن لینک",
     "You can invite others in the participant tab of the sidebar" : "شما می‌توانید دیگران را از زبانه اعضا در نوارکناری دعوت کنید",
     "Share this link to invite others!" : "این پیوند را به اشتراک بگذارید تا دیگران را دعوت کنید!",
+    "Settings" : "تنظیمات",
     "Dismiss" : "پنهان کن",
     "Back" : "بازگشت",
     "You" : "شما",
@@ -273,6 +272,13 @@ OC.L10N.register(
     "Favorite" : "برگزیده",
     "Password protection" : "Password protection",
     "Enter a password" : "یک گذرواژه وارد کنید",
+    "Save" : "ذخیره",
+    "Edit" : "ویرایش",
+    "Password" : "گذرواژه",
+    "API token" : "API token",
+    "Login" : "ورود",
+    "Nickname" : "نام مستعار",
+    "Client ID" : "شناسه مشتری",
     "Leave conversation" : "ترک صحبت",
     "Delete conversation" : "مکالمه را حذف کنید",
     "Remove from favorites" : "Remove from favorites",
@@ -280,7 +286,6 @@ OC.L10N.register(
     "Loading" : "در حال بار گزاری",
     "Groups" : "گروه ها",
     "Circles" : "حلقه ها",
-    "Settings" : "تنظیمات",
     "Create a new group conversation" : "ساخت گفتگوی گروهی جدید",
     "Password protect" : "نگهداری کردن رمز عبور",
     "Add participants" : "افزودن عضو",
@@ -293,13 +298,6 @@ OC.L10N.register(
     "Today" : "Today",
     "Yesterday" : "دیروز",
     "Send message" : "پیام فرستادن",
-    "Enabled" : "فعال شده",
-    "Save" : "ذخیره",
-    "Password" : "گذرواژه",
-    "API token" : "API token",
-    "Login" : "ورود",
-    "Nickname" : "نام مستعار",
-    "Client ID" : "شناسه مشتری",
     "guest" : "میهمان",
     "Demote from moderator" : "عزل از مدیر",
     "Promote to moderator" : "ترفیع به مدیر",
@@ -308,7 +306,6 @@ OC.L10N.register(
     "No results" : "نتیجه ای یافت نشد",
     "Add users or groups" : "کاربران یا گروه ها را اضافه کنید",
     "Participants" : "شركت كنندگان",
-    "Edit" : "ویرایش",
     "Keyboard shortcuts" : "میان بر صفحه ی کلید",
     "Search" : "جستجو کردن",
     "Rename conversation" : "تغییر نام مکالمه",
@@ -323,14 +320,11 @@ OC.L10N.register(
     "The password is wrong. Try again." : "رمزعبور اشتباه می باشد. دوباره امتحان کنید.",
     "Android app" : "اپ اندروید",
     "iOS app" : "اپ iOS",
-    "Contacts" : "مخاطبین",
+    "New in Talk 6" : "جدید در Talk 6",
+    "New in Talk 7" : "جدید در Talk 7",
     "Add participants to the conversation" : "افزودن عضو به گفتگو",
-    "Guests" : "میهمان ها",
-    "Share link" : "Share link",
-    "Webinar" : "وبینار",
     "Projects" : "پروژه ها",
-    "Password required" : "رمز عبور لازم است",
-    "Cancel" : "لغو",
-    "Submit" : "ارسال"
+    "Share link" : "Share link",
+    "Enabled" : "فعال شده"
 },
 "nplurals=2; plural=(n > 1);");
