@@ -13,7 +13,6 @@ OC.L10N.register(
     "{actor} invited you to {call}" : "{actor} kutsui sinut puheluun {call}",
     "Talk" : "Puhe",
     "Guest" : "Vieras",
-    "New in Talk 6" : "Uutta Talkin 6-versiossa",
     "The command does not exist" : "Komentoa ei ole olemassa",
     "Talk updates ✅" : "Talk-päivitykset ✅",
     "{actor} created the conversation" : "{actor} loi keskustelun",
@@ -216,9 +215,6 @@ OC.L10N.register(
     "STUN servers" : "STUN-palvelimet",
     "TURN server URL" : "TURN-palvelimen osoite",
     "TURN server protocols" : "TURN-palvelimen protokollat",
-    "UDP and TCP" : "UDP ja TCP",
-    "UDP only" : "Vain UDP",
-    "TCP only" : "Vain TCP",
     "Test this server" : "Testaa tämä palvelin",
     "TURN servers" : "TURN-palvelin",
     "Copy link" : "Kopioi linkki",
@@ -232,6 +228,7 @@ OC.L10N.register(
     "Share a single window" : "Jaa yksittäinen ikkuna",
     "Show your screen" : "Näytä oma näyttösi",
     "Stop screensharing" : "Lopeta näytön jakaminen",
+    "Settings" : "Asetukset",
     "Dismiss" : "Hylkää",
     "No audio" : "Ei ääntä",
     "Mute audio (m)" : "Mykistä äänet (m)",
@@ -262,8 +259,30 @@ OC.L10N.register(
     "Conversation settings" : "Keskustelun asetukset",
     "Password protection" : "Salasanasuojaus",
     "Enter a password" : "Syötä salasana",
+    "Copy conversation link" : "Kopioi keskustelulinkki",
     "Enable lobby" : "Käytä aulaa",
     "Start time (optional)" : "Aloitusaika (valinnainen)",
+    "Save" : "Tallenna",
+    "Edit" : "Muokkaa",
+    "Nextcloud user" : "Nextcloud-käyttäjä",
+    "Matrix channel" : "Matrix-kanava",
+    "Mattermost user" : "Mattermost-käyttäjä",
+    "Channel name" : "Kanavan nimi",
+    "User name or e-mail address" : "Käyttäjänimi tai sähköpostiosoite",
+    "Password" : "Salasana",
+    "Rocket.Chat channel" : "Rocket.Chat-kanava",
+    "API token" : "API-poletti",
+    "Login" : "Kirjaudu",
+    "Nickname" : "Nimimerkki",
+    "Connection password" : "Yhteyden salasana",
+    "IRC channel" : "IRC-kanava",
+    "NickServ nickname" : "NickServ-nimimerkki",
+    "NickServ password" : "NickServ-salasana",
+    "Use TLS" : "Käytä TLS:ää",
+    "Use SASL" : "Käytä SASL:ia",
+    "Skip TLS verification" : "Ohita TLS-vahvistus",
+    "Client ID" : "Asiakkaan tunniste",
+    "Bridge saved" : "Silta tallennettu",
     "Chat notifications" : "Keskusteluilmoitukset",
     "Leave conversation" : "Poistu keskustelusta",
     "Delete conversation" : "Poista keskustelu",
@@ -276,14 +295,13 @@ OC.L10N.register(
     "No search results" : "Ei hakutuloksia",
     "Groups" : "Ryhmät",
     "Circles" : "Piirit",
-    "Settings" : "Asetukset",
     "Users, groups and circles" : "Käyttäjät, ryhmät ja piirit",
     "Users and groups" : "Käyttäjät ja ryhmät",
     "Users and circles" : "Käyttäjät ja piirit",
     "Groups and circles" : "Ryhmät ja piirit",
     "Other sources" : "Muut lähteet",
+    "An error occurred while performing the search" : "Hakua suorittaessa tapahtui virhe",
     "Creating your conversation" : "Luodaan keskustelua",
-    "Copy conversation link" : "Kopioi keskustelulinkki",
     "Error while creating the conversation" : "Virhe keskustelua luotaessa",
     "Link copied to the clipboard!" : "Linkki kopioitu leikepöydälle!",
     "Create a new group conversation" : "Luo uusi ryhmäkeskustelu",
@@ -293,7 +311,6 @@ OC.L10N.register(
     "Close" : "Sulje",
     "Choose a password" : "Valitse salasana",
     "Search participants" : "Etsi osallistujia",
-    "An error occurred while performing the search" : "Hakua suorittaessa tapahtui virhe",
     "Conversation name" : "Keskustelun nimi",
     "Allow guests to join via link " : "Salli vieraiden liittyminen linkin kautta",
     "Search conversations or users" : "Hae keskusteluja tai käyttäjiä",
@@ -318,30 +335,6 @@ OC.L10N.register(
     "File to share" : "Jaettava tiedosto",
     "Write message, @ to mention someone …" : "Kirjoita viesti, käytä @-merkkiä mainitaksesi käyttäjän…",
     "Invalid path selected" : "Valittu virheellinen polku",
-    "Bridge with other services" : "Siltaa muiden palvelujen kanssa",
-    "More info on Matterbridge." : "Lisätietoja Matterbridgestä.",
-    "Enabled" : "Käytössä",
-    "Show matterbridge log" : "Näytä matterbridge-loki",
-    "Save" : "Tallenna",
-    "Nextcloud user" : "Nextcloud-käyttäjä",
-    "Matrix channel" : "Matrix-kanava",
-    "Mattermost user" : "Mattermost-käyttäjä",
-    "Channel name" : "Kanavan nimi",
-    "User name or e-mail address" : "Käyttäjänimi tai sähköpostiosoite",
-    "Password" : "Salasana",
-    "Rocket.Chat channel" : "Rocket.Chat-kanava",
-    "API token" : "API-poletti",
-    "Login" : "Kirjaudu",
-    "Nickname" : "Nimimerkki",
-    "Connection password" : "Yhteyden salasana",
-    "IRC channel" : "IRC-kanava",
-    "NickServ nickname" : "NickServ-nimimerkki",
-    "NickServ password" : "NickServ-salasana",
-    "Use TLS" : "Käytä TLS:ää",
-    "Use SASL" : "Käytä SASL:ia",
-    "Skip TLS verification" : "Ohita TLS-vahvistus",
-    "Client ID" : "Asiakkaan tunniste",
-    "Bridge saved" : "Silta tallennettu",
     "moderator" : "moderaattori",
     "guest" : "vieras",
     "Demote from moderator" : "Alenna moderaattorista",
@@ -361,7 +354,6 @@ OC.L10N.register(
     "Participants" : "Osallistujat",
     "Chat" : "Keskustelu",
     "Display name: " : "Näyttönimi:",
-    "Edit" : "Muokkaa",
     "Choose devices" : "Valitse laitteet",
     "Attachments folder" : "Liitteiden kansio",
     "Keyboard shortcuts" : "Pikanäppäimet",
@@ -387,15 +379,14 @@ OC.L10N.register(
     "Mention room" : "Mainitse huone",
     "The conversation does not exist" : "Tätä keskustelua ei ole olemassa",
     "Join a conversation or start a new one!" : "Liity keskusteluun tai aloita uusi keskustelu!",
-    "Link to a conversation" : "Linkki keskusteluun",
     "Select conversation" : "Valitse keskustelu",
+    "Link to a conversation" : "Linkki keskusteluun",
     "Join a conversation or start a new one" : "Liity keskusteluun tai aloita uusi",
     "Do not disturb" : "Älä häiritse",
     "Away" : "Poissa",
     "Error while sharing file" : "Virhe tiedostoa jakaessa",
     "Join here" : "Liity tähän",
     "Leave this page" : "Poistu tältä sivulta",
-    "Error while uploading file" : "Virhe tiedostoa lähettäessä",
     "Default" : "Oletus",
     "Microphone {number}" : "Mikrofoni {number}",
     "Camera {number}" : "Kamera {number}",
@@ -415,36 +406,22 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Liity keskusteluihin milloin tahansa, mistä tahansa ja miltä tahansa laitteelta.",
     "Android app" : "Android-sovellus",
     "iOS app" : "iOS-sovellus",
+    "New in Talk 6" : "Uutta Talkin 6-versiossa",
     "{user} wants to talk with you" : "{user} haluaa puhua kanssasi",
-    "No other people in this call" : "Ei muita henkilöitä tässä puhelussa",
-    "Your screen" : "Sinun näyttösi",
-    "Contacts" : "Yhteystiedot",
-    "Contacts, groups and circles" : "Yhteystiedot, ryhmät ja piirit",
-    "Contacts and groups" : "Yhteystiedot ja ryhmät",
-    "Contacts and circles" : "Yhteystiedot ja piirit",
-    "Loading contacts" : "Ladataan yhteystietoja",
-    "Select participants" : "Valitse osallistujat",
-    "Search conversations or contacts" : "Hae keskusteluja tai yhteystietoja",
-    "[Unknown user name]" : "[Tuntematon käyttäjänimi]",
-    "Contacts loading" : "Yhteystiedot latautuvat",
-    "Add participants to the conversation" : "Lisää osallistujia keskusteluun",
-    "Add contacts" : "Lisää yhteystietoja",
-    "Add contacts, groups or circles" : "Lisää yhteystietoja, ryhmiä tai piirejä",
-    "Add contacts or groups" : "Lisää yhteystietoja tai ryhmiä",
-    "Add contacts or circles" : "Lisää yhteystietoja tai piirejä",
-    "Guests" : "Vieraat",
-    "Share link" : "Jaa linkki",
-    "Webinar" : "Webinaari",
-    "Projects" : "Projektit",
-    "Limit app usage to groups." : "Rajoita sovelluksen käyttö ryhmiin.",
-    "Who can start a call?" : "Kuka voi aloittaa puhelun?",
-    "Select a conversation to add to the project" : "Valitse projektiin lisättävä keskustelu",
-    "Please enter the password for this call" : "Anna salasana tälle puhelulle",
-    "Password required" : "Salasana vaaditaan",
-    "Cancel" : "Peru",
-    "Submit" : "Lähetä",
+    "UDP and TCP" : "UDP ja TCP",
+    "UDP only" : "Vain UDP",
+    "TCP only" : "Vain TCP",
     "This conversation is read only" : "Keskustelu on kirjoitussuojattu",
     "Default location for attachments" : "Oletussijainti liitteille",
-    "Select default location for attachments" : "Valitse liitteiden oletussijainti"
+    "Select default location for attachments" : "Valitse liitteiden oletussijainti",
+    "Add participants to the conversation" : "Lisää osallistujia keskusteluun",
+    "Projects" : "Projektit",
+    "Share link" : "Jaa linkki",
+    "Select a conversation to add to the project" : "Valitse projektiin lisättävä keskustelu",
+    "Error while uploading file" : "Virhe tiedostoa lähettäessä",
+    "Bridge with other services" : "Siltaa muiden palvelujen kanssa",
+    "More info on Matterbridge." : "Lisätietoja Matterbridgestä.",
+    "Enabled" : "Käytössä",
+    "Show matterbridge log" : "Näytä matterbridge-loki"
 },
 "nplurals=2; plural=(n != 1);");
