@@ -15,10 +15,7 @@ OC.L10N.register(
     "Talk" : "שיחה",
     "Guest" : "אורח/ת",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "ברוך בואך ל־Talk מבית Nextcloud!\nבדיון הזה נעדכן אותך בנוגע לתכונות החדשות שזמינות ב־Talk מבית Nextcloud.",
-    "New in Talk 6" : "חדש ב־Talk 6",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- ניתן מעתה להשתמש ב־Microsoft Edge וב־Safari כדי להשתת, בשיחות שמע ווידאו",
-    "New in Talk 7" : "חדש ב־Talk 7",
-    "New in Talk 8" : "חדש ב־Talk 8",
     "There are currently no commands available." : "אין פקודות זמינות.",
     "The command does not exist" : "הפקודה לא קיימת",
     "An error occurred while running the command. Please ask an administrator to check the logs." : "אירעה שגיאה בעת הפעלת הפקודה. נא לבקש מהנהלת המערכת לבדוק את יומן התיעוד.",
@@ -55,10 +52,19 @@ OC.L10N.register(
     "You added {user}" : "הוספת את {user}",
     "{actor} added you" : "נוספת על ידי {actor}",
     "You left the conversation" : "עזבת את הדיון",
+    "Conversation invitation" : "הזמנה לדיון",
+    "Click the button below to join." : "יש ללחוץ על הכפתור שלהלן כדי להצטרף.",
+    "Meeting ID" : "מזהה פגישה",
+    "Password request: %s" : "בקשת ססמה: %s",
+    "Private conversation" : "דיון פרטי",
+    "Deleted user (%s)" : "משתמש שנמחק (%s)",
     "{user} sent you a private message" : "התקבלה הודעה פרטית מאת {user}",
     "{user} invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי {user}",
     "Join call" : "הצטרפות לשיחה",
     "{user} invited you to a group conversation: {call}" : "הוזמנת על ידי {user} לדיון קבוצתי: {call}",
+    "Answer call" : "לענות לשיחה",
+    "Call back" : "להתקשר בחזרה",
+    "You missed a call from {user}" : "החמצת שיחה עם {user}",
     "A group call has started in {call}" : "החלה שיחה קבוצתית תחת {call}",
     "Open settings" : "פתיחת הגדרות",
     "Conversations" : "דיונים",
@@ -354,9 +360,6 @@ OC.L10N.register(
     "A STUN server is used to determine the public IP address of participants behind a router." : "שרת STUN משמש לאיתור כתובת ה־IP הציבורית של המשתמשים מאחורי נתב.",
     "TURN server URL" : "כתובת שרת TURN",
     "TURN server protocols" : "פרוטוקולים לשרתים מסוג TURN",
-    "UDP and TCP" : "UDP ו־TCP",
-    "UDP only" : "UDP בלבד",
-    "TCP only" : "TCP בלבד",
     "Copy link" : "העתקת קישור",
     "Waiting for others to join the call …" : "בהמתנה לאחרים להצטרף לשיחה…",
     "You can invite others in the participant tab of the sidebar" : "ניתן להזמין אחרים בלשונית המשתתפים בסרגל הצד",
@@ -364,6 +367,7 @@ OC.L10N.register(
     "Share this link to invite others!" : "יש לשתף את הקישור הזה כדי להזמין אחרים!",
     "Show your screen" : "הצגת המסך שלך",
     "Stop screensharing" : "הפסקת שיתוף המסך",
+    "Settings" : "הגדרות",
     "Dismiss" : "התעלמות",
     "No audio" : "אין שמע",
     "Mute audio (m)" : "השתקת שמע (m)",
@@ -386,10 +390,18 @@ OC.L10N.register(
     "Drop your files to upload" : "יש לגרור לכאן קבצים כדי להעלות",
     "Favorite" : "סימון כמועדף",
     "Conversation settings" : "הגדרות דיון",
-    "Password protection" : "Password protection",
+    "Password protection" : "הגנה בססמה",
     "Enter a password" : "נא להקליד ססמה",
+    "Copy conversation link" : "העתקת קישור דיון",
     "Enable lobby" : "הפעלת לובי",
     "Start time (optional)" : "מועד התחלה (רשות)",
+    "Save" : "שמירה",
+    "Edit" : "עריכה",
+    "Password" : "ססמה",
+    "API token" : "אסימון API",
+    "Login" : "התחבר",
+    "Nickname" : "כינוי",
+    "Client ID" : "מזהה לקו",
     "Leave conversation" : "יציאה מהדיון",
     "Delete conversation" : "מחיקת דיון",
     "Remove from favorites" : "הסרה מהמועדפים",
@@ -397,12 +409,11 @@ OC.L10N.register(
     "Loading" : "בטעינה",
     "Groups" : "קבוצות",
     "Circles" : "מעגלים",
-    "Settings" : "הגדרות",
     "Groups and circles" : "קבוצות ומעגלים",
     "Other sources" : "מקורות אחרים",
+    "An error occurred while performing the search" : "אירעה שגיאה בעת ביצוע החיפוש",
     "Creating your conversation" : "הדיון שלך נוצר",
     "All set" : "הכול מוכן",
-    "Copy conversation link" : "העתקת קישור דיון",
     "Error while creating the conversation" : "שגיאה ביצירת הדיון",
     "Link copied to the clipboard!" : "הקישור הועתק ללוח הגזירים!",
     "Create a new group conversation" : "יצירת דיון קבוצתי חדש",
@@ -412,7 +423,6 @@ OC.L10N.register(
     "Close" : "סגירה",
     "Choose a password" : "בחירת ססמה",
     "Search participants" : "חיפוש משתתפים",
-    "An error occurred while performing the search" : "אירעה שגיאה בעת ביצוע החיפוש",
     "Conversation name" : "שם דיון",
     "Allow guests to join via link " : "לאפשר לאורחים להצטרף דרך קישור",
     "You are currently waiting in the lobby" : "הנך בהמתנה בלובי",
@@ -430,13 +440,6 @@ OC.L10N.register(
     "Send message" : "שליחת הודעה",
     "File to share" : "קובץ לשיתוף",
     "Invalid path selected" : "הנתיב שנבחר שגוי",
-    "Enabled" : "מופעל",
-    "Save" : "שמירה",
-    "Password" : "ססמה",
-    "API token" : "אסימון API",
-    "Login" : "התחבר",
-    "Nickname" : "כינוי",
-    "Client ID" : "מזהה לקו",
     "moderator" : "מפקח/ת",
     "guest" : "אורח",
     "Demote from moderator" : "הורדה מדרגת פיקוח",
@@ -447,14 +450,13 @@ OC.L10N.register(
     "Add circles" : "הוספת מעגלים",
     "Searching …" : "מתבצע חיפוש…",
     "No results" : "אין תוצאות",
-    "Add users or groups" : "Add users or groups",
+    "Add users or groups" : "הוספת משתמשים או קבוצות",
     "Add groups or circles" : "הוספת קבוצות או מעגלים",
     "Add other sources" : "הוספת מקורות אחרים",
     "Participants" : "משתתפים",
     "An error occurred while fetching the participants" : "אירעה שגיאה במהלך קבלת המשתתפים",
     "Chat" : "צ׳אט",
     "Display name: " : "שם תצוגה:",
-    "Edit" : "עריכה",
     "Keyboard shortcuts" : "קיצורי מקלדת",
     "Search" : "חיפוש",
     "Start call" : "התחלת שיחה",
@@ -470,8 +472,8 @@ OC.L10N.register(
     "Mention room" : "אזכור חדר",
     "The conversation does not exist" : "הדיון לא קיים",
     "Join a conversation or start a new one!" : "הצטרפות לדיון או ליצור אחד חדש!",
-    "Link to a conversation" : "קישור לדיון",
     "Select conversation" : "בחירת דיון",
+    "Link to a conversation" : "קישור לדיון",
     "Join a conversation or start a new one" : "ניתן להצטרף לדיון או להתחיל באחד חדש.",
     "Error while sharing file" : "שגיאה בשיתוף הקובץ",
     "Default" : "בררת מחדל",
@@ -486,30 +488,18 @@ OC.L10N.register(
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "שרת ה־TURN משמש לתיווך התעבורה מהמשתמשים שנמצאים מאחורי חומת אש.",
     "Android app" : "יישומון ל־Android",
     "iOS app" : "יישומון ל־iOS",
-    "No other people in this call" : "אין אנשים נוספים בשיחה הזאת",
-    "Your screen" : "המסך שלך",
+    "New in Talk 6" : "חדש ב־Talk 6",
+    "New in Talk 7" : "חדש ב־Talk 7",
+    "New in Talk 8" : "חדש ב־Talk 8",
+    "UDP and TCP" : "UDP ו־TCP",
+    "UDP only" : "UDP בלבד",
+    "TCP only" : "TCP בלבד",
     "Conversation, " : "דיון,",
-    "Contacts" : "אנשי קשר",
-    "Contacts and groups" : "אנשי קשר וקבוצות",
-    "Contacts and circles" : "אנשי קשר ומעגלים",
-    "Search conversations or contacts" : "חיפוש דיונים או אנשי קשר",
-    "[Unknown user name]" : "[שם המשתמש לא ידוע]",
     "Participant settings" : "הגדרות משתתפים",
-    "Search for more contacts" : "חיפוש אחר אנשי קשר נוספים",
     "Add participants to the conversation" : "הוספת משתתפים לדיון",
-    "Add contacts" : "הוספת אנשי קשר",
-    "Add contacts, groups or circles" : "הוספת אנשי קשר, קבוצות או מעגלים",
-    "Add contacts or groups" : "הוספת אנשי קשר או קבוצות",
-    "Add contacts or circles" : "הוספת אנשי קשר או מעגלים",
-    "Guests" : "אורחים",
-    "Share link" : "שיתוף קישור",
-    "Webinar" : "סמינר מקוון",
     "Projects" : "מיזמים",
-    "Limit app usage to groups." : "להגביל את השימוש ביישומון לקבוצות.",
+    "Share link" : "שיתוף קישור",
     "Select a conversation to add to the project" : "בחירת דיון להוספה למיזם",
-    "Please enter the password for this call" : "נא להקליד את הססמה של השיחה הזאת",
-    "Password required" : "נדרשת ססמה",
-    "Cancel" : "ביטול",
-    "Submit" : "שליחה"
+    "Enabled" : "מופעל"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
