@@ -14,8 +14,6 @@ OC.L10N.register(
     "Talk" : "Spjalla",
     "Guest" : "Gestur",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Velkomin í Nextcloud Talk-spjallforritið!\nÍ þessum spjallþræði verður þú upplýst/ur um nýja eigileika sem tiltækir eru í Nextcloud Talk.",
-    "New in Talk 6" : "Nýtt í Talk 6",
-    "New in Talk 7" : "Nýtt í Talk 7",
     "There are currently no commands available." : "Það eru engarskipanir tiltækar í augnablikinu.",
     "The command does not exist" : "Skipunin er ekki til",
     "Talk updates ✅" : "Uppfærslur á Talk-spjallforriti ✅",
@@ -390,9 +388,6 @@ OC.L10N.register(
     "TURN server URL" : "URL-slóð TURN-þjóns",
     "TURN server secret" : "Leynilykill á TURN-miðlara",
     "TURN server protocols" : "Samskiptareglur TURN-þjóns",
-    "UDP and TCP" : "UDP og TCP",
-    "UDP only" : "Aðeins UDP",
-    "TCP only" : "Aðeins TCP",
     "Test this server" : "Prófa þennan þjón",
     "TURN servers" : "TURN-miðlarar",
     "Copy link" : "Afrita tengil",
@@ -404,6 +399,7 @@ OC.L10N.register(
     "Share a single window" : "Deila stökum glugga",
     "Show your screen" : "Birta skjáinn þinn",
     "Stop screensharing" : "Hætta skjádeilingu",
+    "Settings" : "Stillingar",
     "Dismiss" : "Hafna",
     "No audio" : "Ekkert hljóð",
     "Mute audio (m)" : "Þagga hljóð (m)",
@@ -428,6 +424,13 @@ OC.L10N.register(
     "Password protection" : "Verndun með lykilorði",
     "Enter a password" : "Settu inn lykilorð",
     "Start time (optional)" : "Upphafstími (valfrjálst)",
+    "Save" : "Vista",
+    "Edit" : "Breyta",
+    "Password" : "Lykilorð",
+    "API token" : "API-teikn",
+    "Login" : "Innskráning",
+    "Nickname" : "Stuttnefni",
+    "Client ID" : "Biðlaraauðkenni",
     "Leave conversation" : "Hætta í samtali",
     "Delete conversation" : "Eyða samtali",
     "Remove from favorites" : "Fjarlægja úr eftirlætum",
@@ -436,7 +439,6 @@ OC.L10N.register(
     "Loading" : "Hleð inn",
     "Groups" : "Hópar",
     "Circles" : "Hringir",
-    "Settings" : "Stillingar",
     "Password protect" : "Verja með lykilorði",
     "Close" : "Loka",
     "Conversation name" : "Heiti samtals",
@@ -449,13 +451,6 @@ OC.L10N.register(
     "Send message" : "Senda skilaboð",
     "File to share" : "Skrá til að deila",
     "Invalid path selected" : "Ógild slóð valin",
-    "Enabled" : "Virkt",
-    "Save" : "Vista",
-    "Password" : "Lykilorð",
-    "API token" : "API-teikn",
-    "Login" : "Innskráning",
-    "Nickname" : "Stuttnefni",
-    "Client ID" : "Biðlaraauðkenni",
     "moderator" : "umsjónarmaður",
     "guest" : "gestanotandi",
     "Demote from moderator" : "Láta hætta sem umsjónarmann",
@@ -466,7 +461,6 @@ OC.L10N.register(
     "Add users or groups" : "Bæta við notendum eða hópum",
     "Participants" : "Þátttakendur",
     "Chat" : "Spjall",
-    "Edit" : "Breyta",
     "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
     "Search" : "Search",
     "Start call" : "Hefja samtal",
@@ -478,8 +472,8 @@ OC.L10N.register(
     "Send" : "Senda",
     "Say hi to your friends and colleagues!" : "Segðu hæ við vini þína og samstarfsmenn!",
     "Start a conversation" : "Hefja samtal",
-    "Link to a conversation" : "Tengill á samtal",
     "Select conversation" : "Veldu samtal",
+    "Link to a conversation" : "Tengill á samtal",
     "Join a conversation or start a new one" : "Taktu þátt í samtali eða byrjaðu nýtt samtal",
     "Default" : "Sjálfgefið",
     "Access to microphone & camera is only possible with HTTPS" : "Aðgangur að hljóðnema og myndavél er einungis mögulegur í gegnum HTTPS",
@@ -498,21 +492,16 @@ OC.L10N.register(
     "%s Talk on your mobile devices" : "%s Talaðu á snjalltækjunum þínum",
     "Android app" : "Android-forrit",
     "iOS app" : "iOS-forrit",
+    "New in Talk 6" : "Nýtt í Talk 6",
+    "New in Talk 7" : "Nýtt í Talk 7",
     "{user} wants to talk with you" : "{user} vill tala við þig",
-    "No other people in this call" : "Engir aðrir í þessu símtali",
-    "Your screen" : "Skjárinn þinn",
-    "Contacts" : "Tengiliðir",
-    "Search conversations or contacts" : "Leita í samtölum eða tengiliðum",
-    "[Unknown user name]" : "[nafn óþekkts notanda]",
-    "Guests" : "Gestir",
-    "Share link" : "Deila tengli",
+    "Signaling server URL" : "Slóð á merkjasendingaþjón",
+    "UDP and TCP" : "UDP og TCP",
+    "UDP only" : "Aðeins UDP",
+    "TCP only" : "Aðeins TCP",
     "Projects" : "Verkefni",
-    "Limit app usage to groups." : "Takmarka notkun forrits við tiltekna hópa.",
+    "Share link" : "Deila tengli",
     "Select a conversation to add to the project" : "Veldu samtal sem á að bæta við verkefnið",
-    "Please enter the password for this call" : "Settu inn lykilorðið fyrir þetta símtal",
-    "Password required" : "Lykilorðs er krafist",
-    "Cancel" : "Hætta við",
-    "Submit" : "Senda inn",
-    "Signaling server URL" : "Slóð á merkjasendingaþjón"
+    "Enabled" : "Virkt"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
