@@ -15,22 +15,17 @@ OC.L10N.register(
     "Talk" : "Pokalbiai",
     "Guest" : "Svečias",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Sveiki atvykę į Nextcloud Pokalbius!\nŠiame pokalbyje būsite informuojami apie naujas Nextcloud Pokalbiuose prieinamas ypatybes.",
-    "New in Talk 6" : "Kas naujo Pokalbiuose 6",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Dabar, dalyvavimui vaizdo ir garso skambučiuose gali būti naudojamos Microsoft Edge ir Safari naršyklės",
     "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Dabar, pokalbiai vienu du yra išliekantys ir daugiau nebegali būti atsitiktinai paversti į grupės pokalbius. Be to, kai kuris nors vienas dalyvis išeina iš pokalbio, pokalbis daugiau nebėra automatiškai ištrinamas. Tik tuo atveju, jei abu dalyviai išėjo iš pokalbio, pokalbis yra ištrinamas iš serverio",
     "- You can now notify all participants by posting \"@all\" into the chat" : "- Galite siųsti pranešimą visiems dalyviams, pokalbyje parašę \"@all\"",
     "- With the \"arrow-up\" key you can repost your last message" : "- Naudodami klavišą \"rodyklė aukštyn\" galite iš naujo paskelbti savo paskutinę žinutę",
     "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Nuo šiol, Pokalbiuose gali būti komandos. Siųskite pokalbyje žinutę \"/help\" norėdami pamatyti ar jūsų administratorius yra sukonfigūravęs kokias nors komandas",
     "- With projects you can create quick links between conversations, files and other items" : "- Naudodami projektus galite greitai sukurti sąsajas tarp pokalbių, failų bei kitų elementų",
-    "New in Talk 7" : "Kas naujo Pokalbiuose 7",
     "- You can now mention guests in the chat" : "- Dabar, pokalbiuose galite minėti svečius",
     "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Dabar, pokalbiuose yra laukimo salė. Tai leis moderatoriams prisijungti prie pokalbio ir skambinti, kad paruoštų susitikimą, kol tuo tarpu kiti naudotojai ir svečiai turės laukti",
-    "New in Talk 8" : "Nauja Pokalbiuose 8",
     "- You can now directly reply to messages giving the other users more context what your message is about" : "- Dabar, galite tiesiogiai atsakyti į žinutes, suteikdami kitiems naudotojams daugiau konteksto apie ką yra jūsų žinutė",
     "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Dabar, pokalbių ir dalyvių paieška taip pat filtruos ir jūsų esamus pokalbius, todėl bus žymiai lengviau rasti ankstesnius pokalbius",
     "- You can now add custom user groups to conversations when the circles app is installed" : "- Nuo šiol, kai turite įdiegtą ratų programėlę, galite pridėti į pokalbius tinkintas naudotojų grupes",
-    "New in Talk 9" : "Nauja Pokalbiuose 9",
-    "New in Talk 10" : "Nauja Pokalbiuose 10",
     "There are currently no commands available." : "Šiuo metu nėra prieinamų komandų.",
     "The command does not exist" : "Komandos nėra",
     "An error occurred while running the command. Please ask an administrator to check the logs." : "Vykdant komandą, įvyko klaida. Paprašykite administratoriaus, kad patikrintų žurnalus.",
@@ -41,6 +36,12 @@ OC.L10N.register(
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} pervadino pokalbį iš \"%1$s\" į \"%2$s\"",
     "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Jūs pervadinote pokalbį iš \"%1$s\" į \"%2$s\"",
     "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Administratorius pervadino pokalbį iš \"%1$s\" į \"%2$s\"",
+    "{actor} set the description to \"%1$s\"" : "{actor} nustatė aprašą į „%1$s“",
+    "You set the description to \"%1$s\"" : "Jūs nustatėte aprašą į „%1$s“",
+    "An administrator set the description to \"%1$s\"" : "Administratorius nustatė aprašą į „%1$s“",
+    "{actor} removed the description" : "{actor} pašalino aprašą",
+    "You removed the description" : "Jūs pašalinote aprašą",
+    "An administrator removed the description" : "Administratorius pašalino aprašą",
     "{actor} started a call" : "{actor} pradėjo skambutį",
     "You started a call" : "Jūs pradėjote skambutį",
     "{actor} joined the call" : "{actor} prisijungė prie skambučio",
@@ -98,6 +99,10 @@ OC.L10N.register(
     "You updated the Matterbridge configuration." : "Jūs atnaujinote „Matterbridge“ konfigūraciją.",
     "{actor} removed the Matterbridge configuration." : "{actor} pašalino „Matterbridge“ konfigūraciją.",
     "You removed the Matterbridge configuration." : "Jūs pašalinote „Matterbridge“ konfigūraciją.",
+    "{actor} started Matterbridge." : "{actor} paleido „Matterbridge“.",
+    "You started Matterbridge." : "Jūs paleidote „Matterbridge“.",
+    "{actor} stopped Matterbridge." : "{actor} sustabdė „Matterbridge“.",
+    "You stopped Matterbridge." : "Jūs sustabdėte „Matterbridge“.",
     "%s (guest)" : "%s (svečias)",
     "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Skambutis su %n svečiu (Trukmė {duration})","Skambutis su %n svečiais (Trukmė {duration})","Skambutis su %n svečių (Trukmė {duration})","Skambutis %n svečiu (Trukmė {duration})"],
     "Call with {user1} and {user2} (Duration {duration})" : "Skambutis su {user1} ir {user2} (Trukmė {duration})",
@@ -106,6 +111,7 @@ OC.L10N.register(
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Skambutis su {user1}, {user2}, {user3}, {user4} ir {user5} (Trukmė {duration})",
     "Talk to %s" : "Kalbėti su %s",
     "File is not shared, or shared but not with the user" : "Failas nėra bendrinamas arba yra bendrinamas, tačiau ne su naudotoju",
+    "No account available to delete." : "Nėra ištrynimui prieinamos paskyros.",
     "Talk mentions" : "Paminėjimai pokalbiuose",
     "Write to conversation" : "Rašyti į pokalbį",
     "Writes event information into a conversation of your choice" : "Parašo apie įvykio informaciją į jūsų pasirinktą pokalbį",
@@ -417,9 +423,6 @@ OC.L10N.register(
     "TURN server URL" : "TURN serverio URL",
     "TURN server secret" : "TURN serverio paslaptis",
     "TURN server protocols" : "TURN serverio protokolai",
-    "UDP and TCP" : "UDP ir TCP",
-    "UDP only" : "Tik UDP",
-    "TCP only" : "Tik TCP",
     "Test this server" : "Išbandyti šį serverį",
     "TURN servers" : "TURN serveriai",
     "Copy link" : "Kopijuoti nuorodą",
@@ -433,6 +436,7 @@ OC.L10N.register(
     "Share a single window" : "Bendrinti vieną langą",
     "Show your screen" : "Rodyti savo ekraną",
     "Stop screensharing" : "Stabdyti ekrano bendrinimą",
+    "Settings" : "Nustatymai",
     "Dismiss" : "Atmesti",
     "No audio" : "Nėra jokio garso",
     "Mute audio (m)" : "Nutildyti garsą (m)",
@@ -466,8 +470,36 @@ OC.L10N.register(
     "Conversation settings" : "Pokalbio nustatymai",
     "Password protection" : "Apsauga slaptažodžiu",
     "Enter a password" : "Enter a password",
+    "Copy conversation link" : "Kopijuoti pokalbio nuorodą",
     "Enable lobby" : "Įjungti laukimo salę",
     "Start time (optional)" : "Pradžios laikas (nebūtinas)",
+    "Save" : "Įrašyti",
+    "Edit" : "Taisyti",
+    "Nextcloud URL" : "Nextcloud URL",
+    "Nextcloud user" : "Nextcloud naudotojas",
+    "User password" : "Naudotojo slaptažodis",
+    "Matrix server URL" : "Matrix serverio URL",
+    "Matrix channel" : "Matrix kanalas",
+    "Channel name" : "Kanalo pavadinimas",
+    "Rocket.Chat server URL" : "Rocket.Chat serverio URL",
+    "User name or e-mail address" : "Naudotojo vardas ar el. pašto adresas",
+    "Password" : "Slaptažodis",
+    "Rocket.Chat channel" : "Rocket.Chat kanalas",
+    "API token" : "API prieigos raktas",
+    "Slack channel" : "Slack kanalas",
+    "Server ID or name" : "Serverio ID ar pavadinimas",
+    "Channel ID or name" : "Kanalo ID ar pavadinimas",
+    "Channel" : "Kanalas",
+    "Login" : "Prisijungti",
+    "Nickname" : "Slapyvardis",
+    "IRC channel" : "IRC kanalas",
+    "Use TLS" : "Naudoti TLS",
+    "Use SASL" : "Naudoti SASL",
+    "Client ID" : "Kliento ID",
+    "XMPP/Jabber server URL" : "XMPP/Jabber serverio URL",
+    "MUC server URL" : "MUC serverio URL",
+    "Jabber ID" : "Jabber ID",
+    "unknown state" : "nežinoma būsena",
     "Chat notifications" : "Pokalbio pranešimai",
     "Leave conversation" : "Išeiti iš pokalbio",
     "Delete conversation" : "Ištrinti pokalbį",
@@ -481,15 +513,14 @@ OC.L10N.register(
     "No search results" : "Nėra paieškos rezultatų",
     "Groups" : "Grupės",
     "Circles" : "Ratai",
-    "Settings" : "Nustatymai",
     "Users, groups and circles" : "Naudotojai, grupės ir ratai",
     "Users and groups" : "Naudotojai ir grupės",
     "Users and circles" : "Naudotojai ir ratai",
     "Groups and circles" : "Grupės ir ratai",
     "Other sources" : "Kiti šaltiniai",
+    "An error occurred while performing the search" : "Atliekant paiešką, įvyko klaida",
     "Creating your conversation" : "Kuriamas jūsų pokalbis",
     "All set" : "Viskas paruošta",
-    "Copy conversation link" : "Kopijuoti pokalbio nuorodą",
     "Error while creating the conversation" : "Klaida kuriant pokalbį",
     "Link copied to the clipboard!" : "Nuoroda nukopijuota į iškarpinę!",
     "Create a new group conversation" : "Sukurti naują grupės pokalbį",
@@ -498,7 +529,6 @@ OC.L10N.register(
     "Create conversation" : "Sukurti pokalbį",
     "Close" : "Užverti",
     "Search participants" : "Ieškoti dalyvių",
-    "An error occurred while performing the search" : "Atliekant paiešką, įvyko klaida",
     "Conversation name" : "Pokalbio pavadinimas",
     "Allow guests to join via link " : "Leisti svečiams prisijungti per nuorodą",
     "Search conversations or users" : "Ieškoti pokalbių ar naudotojų",
@@ -524,33 +554,6 @@ OC.L10N.register(
     "File to share" : "Failas, kurį bendrinti",
     "Write message, @ to mention someone …" : "Rašykite žinutę, naudokite @ norėdami kažką paminėti…",
     "Invalid path selected" : "Pasirinktas neteisingas kelias",
-    "Enabled" : "Įjungta",
-    "Save" : "Įrašyti",
-    "Nextcloud URL" : "Nextcloud URL",
-    "Nextcloud user" : "Nextcloud naudotojas",
-    "User password" : "Naudotojo slaptažodis",
-    "Matrix server URL" : "Matrix serverio URL",
-    "Matrix channel" : "Matrix kanalas",
-    "Channel name" : "Kanalo pavadinimas",
-    "Rocket.Chat server URL" : "Rocket.Chat serverio URL",
-    "User name or e-mail address" : "Naudotojo vardas ar el. pašto adresas",
-    "Password" : "Slaptažodis",
-    "Rocket.Chat channel" : "Rocket.Chat kanalas",
-    "API token" : "API prieigos raktas",
-    "Slack channel" : "Slack kanalas",
-    "Server ID or name" : "Serverio ID ar pavadinimas",
-    "Channel ID or name" : "Kanalo ID ar pavadinimas",
-    "Login" : "Prisijungti",
-    "Nickname" : "Slapyvardis",
-    "IRC channel" : "IRC kanalas",
-    "Use TLS" : "Naudoti TLS",
-    "Use SASL" : "Naudoti SASL",
-    "Client ID" : "Kliento ID",
-    "XMPP/Jabber server URL" : "XMPP/Jabber serverio URL",
-    "MUC server URL" : "MUC serverio URL",
-    "Jabber ID" : "Jabber ID",
-    "Channel" : "Kanalas",
-    "unknown state" : "nežinoma būsena",
     "moderator" : "moderatorius",
     "guest" : "svečias",
     "Demote from moderator" : "Pažeminti iš moderatorių",
@@ -569,7 +572,6 @@ OC.L10N.register(
     "An error occurred while fetching the participants" : "Gaunant dalyvius, įvyko klaida",
     "Chat" : "Pokalbis",
     "Display name: " : "Rodomas vardas: ",
-    "Edit" : "Taisyti",
     "Choose devices" : "Pasirinkti įrenginius",
     "Attachments folder" : "Priedų aplankas",
     "Keyboard shortcuts" : "Klavišų kombinacijos",
@@ -593,7 +595,6 @@ OC.L10N.register(
     "The conversation does not exist" : "Pokalbio nėra",
     "Join a conversation or start a new one!" : "Prisijunkite prie pokalbio arba pradėkite naują!",
     "Join a conversation or start a new one" : "Prisijunkite prie pokalbio arba pradėkite naują",
-    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Nextcloud Pokalbiai pilnai nepalaiko jūsų naudojamos naršyklės. Naudokite naujausią Mozilla Firefox, Microsoft Edge, Google Chrome ar Apple Safari versiją.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Pokalbiai buvo atnaujinti, įkelkite puslapį iš naujo",
     "Do not disturb" : "Netrukdyti",
     "Away" : "Atsitraukęs",
@@ -623,37 +624,24 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Prisijunkite prie pokalbių bet kur, bet kada, bet kokiame įrenginyje.",
     "Android app" : "Android programėlė",
     "iOS app" : "iOS programėlė",
+    "New in Talk 6" : "Kas naujo Pokalbiuose 6",
+    "New in Talk 7" : "Kas naujo Pokalbiuose 7",
+    "New in Talk 8" : "Nauja Pokalbiuose 8",
+    "New in Talk 9" : "Nauja Pokalbiuose 9",
     "{user} wants to talk with you" : "{user} nori su jumis pakalbėti",
-    "No other people in this call" : "Šiame skambutyje nėra kitų žmonių",
-    "Your screen" : "Jūsų ekranas",
-    "Contacts" : "Adresatai",
-    "Contacts, groups and circles" : "Adresatai, grupės ir ratai",
-    "Contacts and groups" : "Adresatai ir grupės",
-    "Contacts and circles" : "Adresatai ir ratai",
-    "Loading contacts" : "Įkeliami adresatai",
-    "Search conversations or contacts" : "Ieškoti pokalbių ar adresatų",
-    "[Unknown user name]" : "[Nežinomas naudotojo vardas]",
-    "Participant settings" : "Dalyvio nustatymai",
-    "Search for more contacts" : "Ieškoti daugiau adresatų",
-    "Contacts loading" : "Įkeliami adresatai",
-    "Add participants to the conversation" : "Pridėti dalyvius į pokalbį",
-    "Add contacts" : "Pridėti adresatus",
-    "Add contacts, groups or circles" : "Pridėti adresatus, grupes ar ratus",
-    "Add contacts or groups" : "Pridėti adresatus ar grupes",
-    "Add contacts or circles" : "Pridėti adresatus ar ratus",
-    "Guests" : "Svečiai",
-    "Share link" : "Bendrinimo nuoroda",
-    "Webinar" : "Internetinis seminaras",
-    "Projects" : "Projektai",
-    "Start calls" : "Pradeda skambučius",
-    "Who can start a call?" : "Kas gali pradėti skambutį?",
-    "Please enter the password for this call" : "Įveskite šio skambučio slaptažodį",
-    "Password required" : "Reikalingas slaptažodis",
-    "Cancel" : "Atsisakyti",
-    "Submit" : "Pateikti",
     "Signaling server URL" : "Signalinio serverio URL",
+    "UDP and TCP" : "UDP ir TCP",
+    "UDP only" : "Tik UDP",
+    "TCP only" : "Tik TCP",
     "This conversation is read only" : "Šis pokalbis yra tik skaitymui",
     "Default location for attachments" : "Numatytoji priedų vieta",
-    "Select default location for attachments" : "Pasirinkti numatytąją vietą priedams"
+    "Select default location for attachments" : "Pasirinkti numatytąją vietą priedams",
+    "Participant settings" : "Dalyvio nustatymai",
+    "Add participants to the conversation" : "Pridėti dalyvius į pokalbį",
+    "Projects" : "Projektai",
+    "Share link" : "Bendrinimo nuoroda",
+    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Nextcloud Pokalbiai nepalaiko pilnai jūsų naudojamos naršyklės. Naudokite naujausią Mozilla Firefox, Microsoft Edge, Google Chrome ar Apple Safari versiją.",
+    "New in Talk 10" : "Nauja Pokalbiuose 10",
+    "Enabled" : "Įjungta"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
