@@ -14,29 +14,23 @@ OC.L10N.register(
     "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Поканети сте во <strong>разговор</strong> или имате <strong>повик</strong>",
     "Talk" : "Разговор",
     "Guest" : "Гостин",
-    "- Spice up your messages with emojis from the emoji picker" : "- Додадете емотикони на вашите пораки од бирачот на емотикони",
-    "- Spice up your messages with emojis from the emoji picker {emoji}" : "- Додадете емотикони на вашите пораки од бирачот на емотикони {emoji}",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Добредојдовте на Nextcloud Talk!\nВо овој разговор ќе бидете информирани за новите функции достапни во Nextcloud Talk.",
-    "New in Talk 6" : "Ново во Talk 6",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge и Safari сега може да се користат за учество во аудио и видео повици",
     "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Разговорите еден на еден сега се постојани и не можат повеќе случајно да се претвораат во групни разговори. Исто така, кога еден од учесниците го напушта разговорот, разговорот не се брише автоматски. Само ако двајцата учесници заминат, разговорот е избришан од серверот",
     "- You can now notify all participants by posting \"@all\" into the chat" : "- Сега можете да ги известите сите учесници со објавување на „@all“ во разговорот",
     "- With the \"arrow-up\" key you can repost your last message" : "- Со копчето \"стрелка нагоре\" можете повторно да ја објавите вашата последна порака",
     "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Разговорот сега може да има команди, испратете \"/help\" како порака во разговорот за да видите дали вашиот администратор конфигурирал некои",
     "- With projects you can create quick links between conversations, files and other items" : "- Со проекти можете да создадете брзи врски помеѓу разговорите, датотеките и другите ставки",
-    "New in Talk 7" : "Ново во Talk 7",
     "- You can now mention guests in the chat" : "- Сега можете да ги споменете гостите во разговорот",
     "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Разговорите сега можат да имаат лоби. Ова ќе им овозможи на модераторите да се приклучат на разговорот и да се јават за да ја подготват средбата, додека корисниците и гостите треба да почекаат",
-    "New in Talk 8" : "Ново во Talk 8",
     "- You can now directly reply to messages giving the other users more context what your message is about" : "- Сега можете директно да одговорите на пораките што им даваат на другите корисници поголем контекст за што се однесува вашата порака",
     "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Пребарувањето разговори и учесници исто така ќе ги филтрира вашите постојни разговори, што ќе го олесни наоѓањето на претходните разговори",
     "- You can now add custom user groups to conversations when the circles app is installed" : "- Сега можете да додавате кориснички кориснички групи во разговорите кога е инсталирана апликацијата кругови",
-    "New in Talk 9" : "Ново во Talk 9",
     "- Check out the new grid and call view" : "- Проверете ја новата мрежа и прегледот на повикот",
     "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Сега можете да испраќате и повлекувате датотеки директно од вашиот уред во разговорот",
     "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Споделените датотеки сега се отвораат директно во погледот на разговор со апликациите за прегледување",
-    "New in Talk 10" : "Ново во Talk 10",
     "- You can now search for chats and messages in the unified search in the top bar" : "- Сега можете да пребарувате разговори и пораки во унифицираното пребарување во горната лента",
+    "- Spice up your messages with emojis from the emoji picker" : "- Додадете емотикони на вашите пораки од бирачот на емотикони",
     "- You can now change your camera and microphone while being in a call" : "- Сега можете да ги менувате камерата и микрофонот додека сте на повик",
     "There are currently no commands available." : "Моментално нема достапни команди.",
     "The command does not exist" : "Комендата не постои",
@@ -48,6 +42,12 @@ OC.L10N.register(
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} го преименува разговорот од \"%1$s\" во \"%2$s\"",
     "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Го преименувавте разговорот од \"%1$s\" to \"%2$s\"",
     "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Администраторот го преименуваше разговорот од \"%1$s\" во \"%2$s\"",
+    "{actor} set the description to \"%1$s\"" : "{actor} го постави описот во \"%1$s\"",
+    "You set the description to \"%1$s\"" : "Го променивте описот во \"%1$s\"",
+    "An administrator set the description to \"%1$s\"" : "Администраторот го постави описот во \"%1$s\"",
+    "{actor} removed the description" : "{actor} го избриша описот",
+    "You removed the description" : "Го избришавте описот",
+    "An administrator removed the description" : "Администраторот го избриша описот",
     "{actor} started a call" : "{actor} стартуваше повик",
     "You started a call" : "Стартувавте повик",
     "{actor} joined the call" : "{actor} се приклучи кон ковикот",
@@ -117,6 +117,7 @@ OC.L10N.register(
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Повик со {user1}, {user2}, {user3}, {user4} и {user5} (Времетраење {duration})",
     "Talk to %s" : "Разговор со %s",
     "File is not shared, or shared but not with the user" : "Датотеката не е споделена, или е споделена но не со корисници",
+    "No account available to delete." : "Нема сметка достапна за бришење.",
     "Talk mentions" : "Спомнувања",
     "Write to conversation" : "Пишивајте во разговорот",
     "Writes event information into a conversation of your choice" : "Напишете информации за настанот во разговорот по ваш избор",
@@ -125,6 +126,10 @@ OC.L10N.register(
     "Conversation invitation" : "Покана за разговор",
     "Click the button below to join." : "Кликнете на копчето подолу за да се приклучите.",
     "Join »%s«" : "Приклучете се »%s«",
+    "You can also dial-in via phone with the following details" : "Истотака можете да се приклучите преку телефон со следниве детали",
+    "Dial-in information" : "Информации",
+    "Meeting ID" : "ID на средба",
+    "Your PIN" : "Вашиот ПИН",
     "Password request: %s" : "Барање за лозинка: %s",
     "Private conversation" : "Приватен разговор",
     "Deleted user (%s)" : "Избришан корисник (%s)",
@@ -162,6 +167,8 @@ OC.L10N.register(
     "Someone is requesting the password to access {file}" : "Некој побара лозинка за да пристапи до {file}",
     "Someone tried to request the password to access {file}" : "Некој се обиде да побара лозинка за да пристапи до {file}",
     "Open settings" : "Отвори параметри",
+    "The hosted signaling server is now configured and will be used." : "Signaling сервер е конфигуриран и сега ќе се користи.",
+    "The hosted signaling server was removed and will not be used anymore." : "Signaling серверот е избришан и нема да се користи повеќе.",
     "Conversations" : "Разговори",
     "Messages" : "Пораки",
     "{user}" : "{user}",
@@ -508,9 +515,6 @@ OC.L10N.register(
     "STUN server URL" : "STUN сервер URL",
     "STUN servers" : "STUN сервери",
     "TURN server URL" : "TURN сервер URL",
-    "UDP and TCP" : "UDP и TCP",
-    "UDP only" : "Само UDP",
-    "TCP only" : "Само TCP",
     "Test this server" : "Тестирај го овој сервер",
     "TURN servers" : "TURN сервери",
     "Copy link" : "Копирај линк",
@@ -524,6 +528,7 @@ OC.L10N.register(
     "Share a single window" : "Сподели единечен прозор",
     "Show your screen" : "Прикажи го вашиот екран",
     "Stop screensharing" : "Запри споделување на екран",
+    "Settings" : "Параметри",
     "Dismiss" : "Отфрли",
     "No audio" : "Нема аудио",
     "Mute audio (m)" : "Занеми (Mute) го аудиото (m)",
@@ -575,10 +580,28 @@ OC.L10N.register(
     "Call in progress" : "Повик е во тек",
     "Favorite" : "Омилен",
     "Conversation settings" : "Параметри за разговор",
+    "Allow guests" : "Овозможи гости",
     "Password protection" : "Заштитено со лозинка",
     "Enter a password" : "Внесете лозинка",
+    "Copy conversation link" : "копирај линк од разговорот",
     "Enable lobby" : "Овозможи лоби",
     "Start time (optional)" : "Време на почеток (опционално)",
+    "Save" : "Зачувај",
+    "Edit" : "Уреди",
+    "Nextcloud URL" : "Nextcloud URL",
+    "Nextcloud user" : "Nextcloud корисник",
+    "User password" : "Лозинка на корисник",
+    "Talk conversation" : "Talk раговор",
+    "Matrix server URL" : "Matrix сервер URL",
+    "Matrix channel" : "Matrix канал",
+    "User name or e-mail address" : "Корисничко име или е-пошта адреса",
+    "Password" : "Лозинка",
+    "Bot user name" : "Име на ботот",
+    "Bot API key" : "API клуч за ботот",
+    "API token" : "API токен",
+    "Login" : "Login",
+    "Nickname" : "Прекар",
+    "Client ID" : "Клиент ИД",
     "Chat notifications" : "Известувања за разговор",
     "Leave conversation" : "Напушти разговор",
     "Delete conversation" : "Избриши разговор",
@@ -593,14 +616,13 @@ OC.L10N.register(
     "No search results" : "Нема резултати од пребарувањето",
     "Groups" : "Групи",
     "Circles" : "Кругови",
-    "Settings" : "Параметри",
     "Users, groups and circles" : "Корисници, групи и кругови",
     "Users and groups" : "Корисници и групи",
     "Users and circles" : "Корисници и кругови",
     "Groups and circles" : "Групи и кругови",
     "Other sources" : "Други извори",
+    "An error occurred while performing the search" : "Настана грешка при обидот за пребарување",
     "Creating your conversation" : "Креирање на вашиот разговор",
-    "Copy conversation link" : "копирај линк од разговорот",
     "Error while creating the conversation" : "Грешка при креирање на разговор",
     "Link copied to the clipboard!" : "Линкот е копиран во клипборд!",
     "Create a new group conversation" : "Креирајте нов групен разговор",
@@ -610,7 +632,6 @@ OC.L10N.register(
     "Close" : "Затвори",
     "Choose a password" : "Избери лозинка",
     "Search participants" : "Барај учесници",
-    "An error occurred while performing the search" : "Настана грешка при обидот за пребарување",
     "Conversation name" : "Име на разговорот",
     "Allow guests to join via link " : "Дозволи им на гостите да се приклучат преку линк",
     "Search conversations or users" : "Пребарување на разговори или корисници",
@@ -645,23 +666,6 @@ OC.L10N.register(
     "No permission to post messages in this conversation" : "Немате дозвола да испратите порака во овој разговор",
     "Could not post message: {errorMessage}" : "Неможе да се испрати пораката: {errorMessage}",
     "Invalid path selected" : "Избрана невалидна патека",
-    "Bridge with other services" : "Мост со други сервери",
-    "Enabled" : "Овозможен",
-    "Save" : "Зачувај",
-    "Nextcloud URL" : "Nextcloud URL",
-    "Nextcloud user" : "Nextcloud корисник",
-    "User password" : "Лозинка на корисник",
-    "Talk conversation" : "Talk раговор",
-    "Matrix server URL" : "Matrix сервер URL",
-    "Matrix channel" : "Matrix канал",
-    "User name or e-mail address" : "Корисничко име или е-пошта адреса",
-    "Password" : "Лозинка",
-    "Bot user name" : "Име на ботот",
-    "Bot API key" : "API клуч за ботот",
-    "API token" : "API токен",
-    "Login" : "Login",
-    "Nickname" : "Прекар",
-    "Client ID" : "Клиент ИД",
     "moderator" : "модератор",
     "guest" : "гостин",
     "Demote from moderator" : "Деградирај од модератор",
@@ -682,9 +686,9 @@ OC.L10N.register(
     "Participants" : "Учесници",
     "Chat" : "Разговор",
     "Display name: " : "Име:",
-    "Edit" : "Уреди",
     "Choose devices" : "Избери уреди",
     "Attachments folder" : "Папка со прилози",
+    "Privacy" : "Приватност",
     "Keyboard shortcuts" : "Кратенки преку тастатура",
     "Speed up your Talk experience with these quick shortcuts." : "Забрзајте го вашето искуство со овие брзи кратенки.",
     "Focus the chat input" : "Фокусирајте го курсорот на разговорот",
@@ -698,7 +702,6 @@ OC.L10N.register(
     "Select location for attachments" : "Избери локација за прилози",
     "Error while setting attachment folder" : "Грешка при поставување на папка за прилози",
     "Start call" : "Повик",
-    "Use speaker view" : "Користете поглед кон тој што зборува",
     "Toggle fullscreen" : "Вклучи на цел екран",
     "Go to file" : "Оди до датотеката",
     "Rename conversation" : "Преименувај разговор",
@@ -716,8 +719,8 @@ OC.L10N.register(
     "Message without mention" : "Пораки без спомнувања",
     "The conversation does not exist" : "Разговорот не постои",
     "Join a conversation or start a new one!" : "Приклучи се кон разговор или започни нов!",
-    "Link to a conversation" : "Линк до разговорот",
     "Select conversation" : "Избери разговор",
+    "Link to a conversation" : "Линк до разговорот",
     "Join a conversation or start a new one" : "Приклучи се кон разговор или започни нов",
     "Do not disturb" : "Не вознемирувај",
     "Away" : "Далеку",
@@ -726,7 +729,6 @@ OC.L10N.register(
     "Failed to join the conversation. Try to reload the page." : "Неуспешно приклучување кон разговорот, Пробајте да ја превчитате страницата.",
     "Join here" : "Приклучи се овде",
     "Leave this page" : "Напушти ја оваа страна",
-    "Error while uploading file" : "Грешка при прикачување на датотека",
     "Default" : "Стандардно",
     "Microphone {number}" : "Микрофон {number}",
     "Speaker {number}" : "Зборуваат {number}",
@@ -743,39 +745,27 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Придружете се на разговор во секое време, каде и да било, на кој било уред.",
     "Android app" : "Android апликација",
     "iOS app" : "iOS апликација",
+    "New in Talk 6" : "Ново во Talk 6",
+    "New in Talk 7" : "Ново во Talk 7",
+    "New in Talk 8" : "Ново во Talk 8",
+    "New in Talk 9" : "Ново во Talk 9",
     "{user} wants to talk with you" : "{user} сака да разговара со вас",
-    "No other people in this call" : "Нема други луѓе во овој повик",
-    "Your screen" : "Вашиот екран",
-    "Conversation, " : "Разговор,",
-    "Contacts" : "Контакти",
-    "Contacts, groups and circles" : "Контакти, групи и кругови",
-    "Contacts and groups" : "Контакти и групи",
-    "Contacts and circles" : "Контакти и кругови",
-    "Loading contacts" : "Вчитување на контакти",
-    "Select participants" : "Избери учесници",
-    "Search conversations or contacts" : "Пребарување на разговори или контакти",
-    "[Unknown user name]" : "[Непознато корисничко име]",
-    "Search for more contacts" : "Пребарување за повеќе контакти",
-    "Contacts loading" : "Вчитување на контакти",
-    "Add participants to the conversation" : "Додадете учесници кон разговорот",
-    "Add contacts" : "Додади контакти",
-    "Add contacts, groups or circles" : "Додади контакти, групи или кругови",
-    "Add contacts or groups" : "Додади контакти или групи",
-    "Add contacts or circles" : "Додади контакти или кругови",
-    "Guests" : "Гости",
-    "Share link" : "Сподели линк",
-    "Webinar" : "Вебинар",
-    "Projects" : "Проекти",
-    "Limit app usage to groups." : "Ограничување за користење на апликации во групи",
-    "Who can start a call?" : "Кој може да започне повик?",
-    "Select a conversation to add to the project" : "Избери разговор за да го додадете во проект",
-    "Please enter the password for this call" : "Внесете лозинка за да пристапите кон овој разговор",
-    "Password required" : "Потребна е лозинка",
-    "Cancel" : "Откажи",
-    "Submit" : "Испрати",
     "Signaling server URL" : "URL за сервер за сигнализација",
+    "UDP and TCP" : "UDP и TCP",
+    "UDP only" : "Само UDP",
+    "TCP only" : "Само TCP",
     "This conversation is read only" : "Разговорот е само за читање",
+    "Conversation, " : "Разговор,",
     "Default location for attachments" : "Стандардна локација за прилози",
-    "Select default location for attachments" : "Избери стандардна локација за прилози"
+    "Select default location for attachments" : "Избери стандардна локација за прилози",
+    "Add participants to the conversation" : "Додадете учесници кон разговорот",
+    "Projects" : "Проекти",
+    "Use speaker view" : "Користете поглед кон тој што зборува",
+    "Share link" : "Сподели линк",
+    "Select a conversation to add to the project" : "Избери разговор за да го додадете во проект",
+    "Error while uploading file" : "Грешка при прикачување на датотека",
+    "New in Talk 10" : "Ново во Talk 10",
+    "Bridge with other services" : "Мост со други сервери",
+    "Enabled" : "Овозможен"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
