@@ -15,7 +15,6 @@ OC.L10N.register(
     "Talk" : "Falar",
     "Guest" : "Convidado",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Bem-vindo ao Nextcloud Talk!\nNesta conversa será informado sobre novas funcionalidades disponíveis no Nextcloud Talk.",
-    "New in Talk 6" : "Novo em Talk 6",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- O Microsoft Edge e o Safari podem, agora, ser utilizados para participar em chamadas áudio e vídeo.",
     "Talk to %s" : "Falar com %s",
     "Join call" : "Juntar-se à chamada",
@@ -78,13 +77,11 @@ OC.L10N.register(
     "Validate SSL certificate" : "Validar certificado SSL",
     "Saved" : "Gravado",
     "TURN server protocols" : "Protocolos do servidor TURN",
-    "UDP and TCP" : "UDP e TCP",
-    "UDP only" : "Só UDP",
-    "TCP only" : "Só TCP",
     "Copy link" : "Copiar ligação",
     "Waiting for others to join the call …" : "À espera que outros se juntem à chamada ..",
     "You can invite others in the participant tab of the sidebar" : "Pode convidar outros no separador participantes na barra lateral  ",
     "Share this link to invite others!" : "Envie este link para convidar outros!",
+    "Settings" : "Definições",
     "Dismiss" : "Dispensar",
     "Mute audio" : "Silenciar áudio",
     "Disable video" : "desactivar vídeo",
@@ -102,6 +99,13 @@ OC.L10N.register(
     "Favorite" : "Favorito",
     "Password protection" : "Protegido por palavra-passe",
     "Enter a password" : "Insira uma palavra-passe",
+    "Save" : "Guardar",
+    "Edit" : "Editar",
+    "Password" : "Palavra-passe",
+    "API token" : "Token de API",
+    "Login" : "Iniciar sessão",
+    "Nickname" : "Alcunha",
+    "Client ID" : "Id. do Cliente",
     "Leave conversation" : "Sair da conversação",
     "Delete conversation" : "Eliminar conversação",
     "Remove from favorites" : "Remover de favoritos",
@@ -109,7 +113,6 @@ OC.L10N.register(
     "Loading" : "A carregar",
     "Groups" : "Grupos",
     "Circles" : "Círculos",
-    "Settings" : "Definições",
     "Password protect" : "Proteger com palavra-passe",
     "Close" : "Fechar",
     "Conversation name" : "Nome da conversação",
@@ -120,13 +123,6 @@ OC.L10N.register(
     "Yesterday" : "Ontem",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Send message" : "Enviar mensagem",
-    "Enabled" : "Habilidado",
-    "Save" : "Guardar",
-    "Password" : "Palavra-passe",
-    "API token" : "Token de API",
-    "Login" : "Iniciar sessão",
-    "Nickname" : "Alcunha",
-    "Client ID" : "Id. do Cliente",
     "moderator" : "moderador",
     "guest" : "convidado",
     "Demote from moderator" : "Relegar de moderador",
@@ -136,7 +132,6 @@ OC.L10N.register(
     "Add users or groups" : "Add users or groups",
     "Participants" : "Participantes",
     "Chat" : "Conversa",
-    "Edit" : "Editar",
     "Keyboard shortcuts" : "Atalhos de teclado",
     "Search" : "Pesquisa sobre",
     "Rename conversation" : "Renomear conversação",
@@ -152,17 +147,12 @@ OC.L10N.register(
     "The password is wrong. Try again." : "A palavra-passe está errada. Por favor, tente de novo.",
     "Android app" : "Aplicação Android",
     "iOS app" : "Aplicação iOS",
+    "New in Talk 6" : "Novo em Talk 6",
     "{user} wants to talk with you" : "{user} quer falar consigo",
-    "No other people in this call" : "Sem mais pessoas nesta chamada",
-    "Your screen" : "O seu ecrã",
-    "Contacts" : "Contactos",
-    "[Unknown user name]" : "[Nome de utilizador desconhecido]",
-    "Guests" : "Convidados",
+    "UDP and TCP" : "UDP e TCP",
+    "UDP only" : "Só UDP",
+    "TCP only" : "Só TCP",
     "Share link" : "Partilhar hiperligação",
-    "Limit app usage to groups." : "Limitar o uso da aplicação a grupos.",
-    "Please enter the password for this call" : "Por favor introduza a palavra-passe para esta chamada",
-    "Password required" : "Necessário palavra-passe",
-    "Cancel" : "Cancelar",
-    "Submit" : "Submeter"
+    "Enabled" : "Habilidado"
 },
 "nplurals=2; plural=(n != 1);");
