@@ -164,13 +164,11 @@ OC.L10N.register(
     "Blocked" : "I bllokuar",
     "Saved" : "U ruajt",
     "TURN server protocols" : "Protokollet e serverit TURN",
-    "UDP and TCP" : "UDP dhe TCP",
-    "UDP only" : "Vetëm UDP",
-    "TCP only" : "Vetëm TCP",
     "Copy link" : "Kopjo linkun",
     "Waiting for others to join the call …" : "Duke pritur që të tjerët t'i bashkohen thirrjes ...",
     "Show your screen" : "Shfaq ekranin tënd",
     "Stop screensharing" : "Ndalo ndarjen e ekranit",
+    "Settings" : "Rregullimet",
     "Dismiss" : "Hiq",
     "Mute audio" : "Mute audio",
     "Disable video" : "Çaktivizo video",
@@ -184,6 +182,13 @@ OC.L10N.register(
     "Favorite" : "I/E Preferuar",
     "Password protection" : "Password protection",
     "Enter a password" : "Fusni një fjalëkalim",
+    "Save" : "Ruaj",
+    "Edit" : "Përpuno",
+    "Password" : "Fjalëkalim",
+    "API token" : "Çelës identifikues i API-t ",
+    "Login" : "Hyrje",
+    "Nickname" : "Nofkë",
+    "Client ID" : "ID klienti",
     "Leave conversation" : "Largohuni nga biseda",
     "Delete conversation" : "Fshijeni bisedën",
     "Remove from favorites" : "Remove from favorites",
@@ -191,7 +196,6 @@ OC.L10N.register(
     "Loading" : "Duke ngarkuar",
     "Groups" : "Grupet",
     "Circles" : "Rrethet",
-    "Settings" : "Rregullimet",
     "Password protect" : "Mbroje me fjalëkalim",
     "Close" : "Mbylleni",
     "Conversation name" : "Emri i bisedës",
@@ -201,17 +205,9 @@ OC.L10N.register(
     "Today" : "Sot",
     "Yesterday" : "Dje",
     "Send message" : "Dërgo mesazh",
-    "Enabled" : "I aktivizuar",
-    "Save" : "Ruaj",
-    "Password" : "Fjalëkalim",
-    "API token" : "Çelës identifikues i API-t ",
-    "Login" : "Hyrje",
-    "Nickname" : "Nofkë",
-    "Client ID" : "ID klienti",
     "guest" : "vizitor",
     "No results" : "Asnjë rezultat",
     "Add users or groups" : "Add users or groups",
-    "Edit" : "Përpuno",
     "Keyboard shortcuts" : "Shkurtoret e tastierës",
     "Search" : "Kërko",
     "Rename conversation" : "Riemërtojeni bisedën",
@@ -229,13 +225,10 @@ OC.L10N.register(
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "Serveri TURN përdoret për të përcjellë trafikun nga pjesëmarrësit pas një firewalli.",
     "Android app" : "Aplikacion Android",
     "iOS app" : "Aplikacion iOS",
-    "No other people in this call" : "Jo njerëz të tjerë në këtë thirrje",
-    "Your screen" : "Ekrani juaj",
-    "Contacts" : "Kontaktet",
-    "Guests" : "Të ftuarit",
+    "UDP and TCP" : "UDP dhe TCP",
+    "UDP only" : "Vetëm UDP",
+    "TCP only" : "Vetëm TCP",
     "Share link" : "Shpërndaj ndërlidhjen",
-    "Password required" : "Kërkohet fjalëkalimi",
-    "Cancel" : "Anulo",
-    "Submit" : "Dërgo"
+    "Enabled" : "I aktivizuar"
 },
 "nplurals=2; plural=(n != 1);");
