@@ -15,29 +15,39 @@ OC.L10N.register(
     "Talk" : "Talk",
     "Guest" : "Gäst",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Välkommen till Nextcloud Talk!\nI denna konversation kommer du att bli informerad om nya funktioner som finns i Nextcloud Talk.",
-    "New in Talk 6" : "Nytt i Talk 6",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge och Safari kan nu användas för att delta i ljud- och videosamtal",
     "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- En-till-en-konversationer är nu beständiga och kan inte längre omvandlas till gruppsamtal av misstag. När en av deltagarna lämnar samtalet raderas konversationen inte längre automatiskt. Endast om båda deltagarna lämnar samtalet raderas konversationen från servern.",
     "- You can now notify all participants by posting \"@all\" into the chat" : "- Du kan nu meddela alla deltagare genom att skicka \"@all\" till chatten",
     "- With the \"arrow-up\" key you can repost your last message" : "- Med \"pil upp\" -knappen kan du skicka om ditt senaste meddelande",
     "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk kan nu ha kommandon, skicka \"/help\" som ett chattmeddelande för att se om din administratör har konfigurerat några",
     "- With projects you can create quick links between conversations, files and other items" : "- Med projekt kan du skapa snabba länkar mellan konversationer, filer och andra objekt",
-    "New in Talk 7" : "Nytt i Talk 7",
     "- You can now mention guests in the chat" : "- Du kan nu nämna gäster i chatten",
     "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Konversationer kan nu ha en lobby. Detta gör att moderatorer nu kan förbereda mötet, medan användare och gäster måste vänta.",
-    "New in Talk 8" : "Nytt i Talk 8",
     "- You can now directly reply to messages giving the other users more context what your message is about" : "- Du kan nu svara direkt på meddelanden som ger de andra användarna mer sammanhang vad ditt meddelande handlar om",
     "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Sökning efter konversationer och deltagare kommer nu också att filtrera dina befintliga konversationer, vilket gör det mycket lättare att hitta tidigare konversationer",
     "- You can now add custom user groups to conversations when the circles app is installed" : "- Du kan nu lägga till anpassade användargrupper i konversationer när cirkelappen är installerad",
-    "New in Talk 9" : "Nytt i Talk 9",
+    "- Check out the new grid and call view" : "- Kolla in det nya gränssnittet och samtals-vyn",
+    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Nu går det att ladda upp filer direkt med drag'n'drop från din enhet  till chatten",
+    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Delade filer visas nu direkt inuti chatten och öppnas med rätt applikation.",
+    "- You can now search for chats and messages in the unified search in the top bar" : "- Nu kan du söka efter chattar och meddelanden gemensamt från sökrutan i menyn",
+    "- Spice up your messages with emojis from the emoji picker" : "- Snygga till dina meddelanden med emojis",
+    "- You can now change your camera and microphone while being in a call" : "- Nu går det att ändra kameran och mikrofonen medans du sitter i ett samtal",
     "There are currently no commands available." : "Det finns för närvarande inga kommandon tillgängliga.",
     "The command does not exist" : "Kommandot finns inte",
     "An error occurred while running the command. Please ask an administrator to check the logs." : "Ett fel inträffade under körning av kommandot. Be en administratör att kontrollera loggarna.",
     "Talk updates ✅" : "Talk uppdateringar ✅",
     "{actor} created the conversation" : "{actor} skapade konversationen",
     "You created the conversation" : "Du skapade konversationen",
+    "An administrator created the conversation" : "En administratör skapade konversationen",
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} bytte namn på konversationen från \"%1$s\" till \"%2$s\"",
     "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Du bytte namn på konversationen från \"%1$s\" till \"%2$s\"",
+    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "En administratör döpte om konversationen från \"%1$s\" till \"%2$s\"",
+    "{actor} set the description to \"%1$s\"" : "{actor} ändrade beskrivningen till \"%1$s\"",
+    "You set the description to \"%1$s\"" : "Du ändrade beskrivningen till \"%1$s\"",
+    "An administrator set the description to \"%1$s\"" : "En administratör ändrade beskrivningen till \"%1$s\"",
+    "{actor} removed the description" : "{actor} tog bort beskrivningen",
+    "You removed the description" : "Du tog bort beskrivningen",
+    "An administrator removed the description" : "En administratör tog bort beskrivningen",
     "{actor} started a call" : "{actor} startade ett samtal",
     "You started a call" : "Du startade ett samtal",
     "{actor} joined the call" : "{actor} gick med i samtalet",
@@ -46,8 +56,10 @@ OC.L10N.register(
     "You left the call" : "Du lämnade samtalet",
     "{actor} unlocked the conversation" : "{actor} låste upp konversationen",
     "You unlocked the conversation" : "Du låste upp konversationen",
+    "An administrator unlocked the conversation" : "En administratör låste upp konversationen",
     "{actor} locked the conversation" : "{actor} låste konversationen",
     "You locked the conversation" : "Du låste konversationen",
+    "An administrator locked the conversation" : "En administratör låste konversationen",
     "The conversation is now open to everyone" : "Konversationen är nu öppen för alla",
     "{actor} opened the conversation to everyone" : "{actor} öppnade konversationen för alla",
     "You opened the conversation to everyone" : "Du öppnade konversationen för alla",
@@ -55,30 +67,44 @@ OC.L10N.register(
     "You restricted the conversation to moderators" : "Du begränsade konversationen till moderatorer",
     "{actor} allowed guests" : "{actor} tillåter gäster",
     "You allowed guests" : "Du tillåter gäster",
+    "An administrator allowed guests" : "En administratör har tillåtit gäster",
     "{actor} disallowed guests" : "{actor} tillåter inte gäster",
     "You disallowed guests" : "Du tillåter inte gäster",
+    "An administrator disallowed guests" : "En administratör tillåter inte gäster",
     "{actor} set a password" : "{actor} satte ett lösenord",
     "You set a password" : "Du satte ett lösenord",
+    "An administrator set a password" : "En administratör har aktiverat ett lösenord",
     "{actor} removed the password" : "{actor} tog bort lösenordet",
     "You removed the password" : "Du tog bort lösenordet",
+    "An administrator removed the password" : "En administratör har tagit bort lösenordet",
     "{actor} added {user}" : "{actor} la till {user}",
     "You joined the conversation" : "Du gick med i konversationen",
     "{actor} joined the conversation" : "{actor} gick med i konversationen",
-    "You added {user}" : "Du la till {user}",
-    "{actor} added you" : "{actor} la till dig",
+    "You added {user}" : "Du lade till {user}",
+    "{actor} added you" : "{actor} lade till dig",
+    "An administrator added you" : "En administratör lade till dig",
+    "An administrator added {user}" : "En administratör lade till {user}",
     "You left the conversation" : "Du lämnade konversationen",
     "{actor} left the conversation" : "{actor} lämnade konversationen",
     "{actor} removed {user}" : "{actor} tog bort {user}",
     "You removed {user}" : "Du tog bort {user}",
     "{actor} removed you" : "{actor} tog bort dig",
+    "An administrator removed you" : "En administratör tog bort dig",
+    "An administrator removed {user}" : "En administratör tog bort {user}",
     "{actor} promoted {user} to moderator" : "{actor} gjorde {user} till moderator",
     "You promoted {user} to moderator" : "Du gjorde {user} till moderator",
     "{actor} promoted you to moderator" : "{actor} gjorde dig moderator",
+    "An administrator promoted you to moderator" : "En administratör gjorde dig till moderator",
+    "An administrator promoted {user} to moderator" : "En administratör gjorde {user} till moderator",
     "{actor} demoted {user} from moderator" : "{actor} tog bort {user} som moderator",
     "You demoted {user} from moderator" : "Du tog bort {user} som moderator",
     "{actor} demoted you from moderator" : "{actor} tog bort dig som moderator",
+    "An administrator demoted you from moderator" : "En administratör tog bort dig som moderator",
+    "An administrator demoted {user} from moderator" : "En administratör tog bort {user} som moderator",
     "{actor} shared a file which is no longer available" : "{actor} delade en fil som inte längre är tillgänglig",
     "You shared a file which is no longer available" : "Du delade en fil som inte längre är tillgänglig",
+    "{actor} set up Matterbridge to synchronize this conversation with other chats." : "{actor} aktiverade Matterbridge för att synkronisera denna konversation med andra chattar",
+    "You set up Matterbridge to synchronize this conversation with other chats." : "Du aktiverade Matterbridge för att synkronisera denna konversation med andra chattar",
     "%s (guest)" : "%s (gäst)",
     "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Samtal med %n gäst (Varaktighet {duration})","Samtal med %n gäster (Varaktighet {duration})"],
     "Call with {user1} and {user2} (Duration {duration})" : "Samtal med {user1} och {user2} (Varade {duration})",
@@ -87,6 +113,7 @@ OC.L10N.register(
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Samtal med {user1}, {user2}, {user3}, {user4} och {user5} (Varade {duration})",
     "Talk to %s" : "Prata med %s",
     "File is not shared, or shared but not with the user" : "Filen delas inte eller delas men inte med användaren",
+    "Talk mentions" : "Omnämningar",
     "Write to conversation" : "Skriv till konversation",
     "Writes event information into a conversation of your choice" : "Skriver händelseinformation till en konversation du väljer",
     "%s invited you to a conversation." : "%s bjöd in dig till en konversation.",
@@ -94,9 +121,15 @@ OC.L10N.register(
     "Conversation invitation" : "Inbjudan till konversation",
     "Click the button below to join." : "Klicka på knappen nedan för att gå med.",
     "Join »%s«" : "Anslut »%s«",
+    "You can also dial-in via phone with the following details" : "Det går också att ringa-upp via telefon med följande information",
+    "Dial-in information" : "Uppringningsinformation",
+    "Meeting ID" : "Mötes-ID",
+    "Your PIN" : "Din pinkod",
     "Password request: %s" : "Lösenordsförfrågan: %s",
     "Private conversation" : "Privat konversation",
     "Deleted user (%s)" : "Raderad användare (%s)",
+    "{user} in {call}" : "{user} i {call}",
+    "Deleted user in {call}" : "Tog bort användare från {call}",
     "{user} sent you a private message" : "{user} skickade dig ett privat meddelande",
     "{user} sent a message in conversation {call}" : "{user} skickade ett meddelande i konversation {call}",
     "A deleted user sent a message in conversation {call}" : "En raderad användare skickade ett meddelande i konversation {call}",
@@ -445,9 +478,6 @@ OC.L10N.register(
     "TURN server URL" : "TURN-serverwebbadress",
     "TURN server secret" : "TURN-server hemlighet",
     "TURN server protocols" : "TURN-server protokoll",
-    "UDP and TCP" : "UDP och TCP",
-    "UDP only" : "endast UDP",
-    "TCP only" : "endast TCP",
     "Test this server" : "Testa denna server",
     "TURN servers" : "TURN-servrar",
     "Copy link" : "Kopiera länk",
@@ -461,6 +491,7 @@ OC.L10N.register(
     "Share a single window" : "Dela ett fönster",
     "Show your screen" : "Visa din skärm",
     "Stop screensharing" : "Stoppa skärmdelning",
+    "Settings" : "Inställningar",
     "Dismiss" : "Avfärda",
     "No audio" : "Inget ljud",
     "Mute audio (m)" : "Ljud av (m)",
@@ -496,8 +527,16 @@ OC.L10N.register(
     "Conversation settings" : "Konversationsinställningar",
     "Password protection" : "Lösenordsskydd",
     "Enter a password" : "Ange ett lösenord",
+    "Copy conversation link" : "Kopiera konversationslänk",
     "Enable lobby" : "Aktivera lobbyn",
     "Start time (optional)" : "Starttid (valfritt)",
+    "Save" : "Spara",
+    "Edit" : "Ändra",
+    "Password" : "Lösenord",
+    "API token" : "API-token",
+    "Login" : "Logga in",
+    "Nickname" : "Smeknamn",
+    "Client ID" : "Klient-ID",
     "Chat notifications" : "Chatt-aviseringar",
     "Leave conversation" : "Lämna konversationen",
     "Delete conversation" : "Ta bort konversationen",
@@ -512,15 +551,14 @@ OC.L10N.register(
     "No search results" : "Inga sökresultat",
     "Groups" : "Grupper",
     "Circles" : "Cirklar",
-    "Settings" : "Inställningar",
     "Users, groups and circles" : "Användare, grupper och cirklar",
     "Users and groups" : "Användare och grupper",
     "Users and circles" : "Användare och cirklar",
     "Groups and circles" : "Grupper och cirklar",
     "Other sources" : "Andra källor",
+    "An error occurred while performing the search" : "Ett fel uppstod när sökningen utfördes",
     "Creating your conversation" : "Skapar din konversation",
     "All set" : "Allt klart",
-    "Copy conversation link" : "Kopiera konversationslänk",
     "Error while creating the conversation" : "Fel uppstod när konversationen skulle skapas",
     "Link copied to the clipboard!" : "Länken kopierad till urklipp!",
     "Create a new group conversation" : "Skapa en ny gruppkonversation",
@@ -530,7 +568,6 @@ OC.L10N.register(
     "Close" : "Stäng",
     "Choose a password" : "Välj ett lösenord",
     "Search participants" : "Sök deltagare",
-    "An error occurred while performing the search" : "Ett fel uppstod när sökningen utfördes",
     "Conversation name" : "Konversationens namn",
     "Allow guests to join via link " : "Tillåt gäster att ansluta via länk",
     "Search conversations or users" : "Sök konversationer eller användare",
@@ -550,13 +587,6 @@ OC.L10N.register(
     "File to share" : "Fil att dela",
     "Write message, @ to mention someone …" : "Skriv meddelande, @ för att nämna någon ...",
     "Invalid path selected" : "Ogiltig sökväg vald",
-    "Enabled" : "Aktiverad",
-    "Save" : "Spara",
-    "Password" : "Lösenord",
-    "API token" : "API-token",
-    "Login" : "Logga in",
-    "Nickname" : "Smeknamn",
-    "Client ID" : "Klient-ID",
     "moderator" : "moderator",
     "guest" : "gäst",
     "Demote from moderator" : "Degradera från moderator",
@@ -579,7 +609,6 @@ OC.L10N.register(
     "An error occurred while fetching the participants" : "Ett fel uppstod när deltagarna hämtades",
     "Chat" : "Chat",
     "Display name: " : "Visningsnamn:",
-    "Edit" : "Ändra",
     "Keyboard shortcuts" : "Tangentbordsgenvägar",
     "Search" : "Sök",
     "Error while setting attachment folder" : "Fel vid inställning av mapp för bilagor",
@@ -600,16 +629,14 @@ OC.L10N.register(
     "Mention room" : "Nämn rum",
     "The conversation does not exist" : "Konversationen finns inte",
     "Join a conversation or start a new one!" : "Anslut till en konversation eller starta en ny!",
-    "Link to a conversation" : "Länka till en konversation",
     "Select conversation" : "Välj konversation",
+    "Link to a conversation" : "Länka till en konversation",
     "Join a conversation or start a new one" : "Anslut till en konversation eller starta en ny",
-    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Webbläsaren du använder stöds inte av Nextcloud Talk. Använd den senaste versionen av Mozilla Firefox, Microsoft Edge, Google Chrome eller Apple Safari.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk uppdaterades, ladda om sidan igen",
     "Do not disturb" : "Stör ej",
     "Away" : "Iväg",
     "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud är i underhållsläge, ladda om sidan igen",
     "Error while sharing file" : "Fel vid delning av fil",
-    "Error while uploading file" : "Fel vid uppladdning av fil",
     "Sending signaling message has failed." : "Misslyckades skicka signalmeddelande.",
     "Establishing signaling connection is taking longer than expected …" : "Det tar längre tid än förväntat att upprätta signalanslutning ...",
     "Failed to establish signaling connection. Retrying …" : "Det gick inte att upprätta signalanslutning. Försöker igen ...",
@@ -634,42 +661,28 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Gå med i konversationer när som helst, var som helst, på alla enheter.",
     "Android app" : "Android-app",
     "iOS app" : " iOS-app",
+    "New in Talk 6" : "Nytt i Talk 6",
+    "New in Talk 7" : "Nytt i Talk 7",
+    "New in Talk 8" : "Nytt i Talk 8",
+    "New in Talk 9" : "Nytt i Talk 9",
     "{user} wants to talk with you" : "{user} vill prata med dig",
-    "No other people in this call" : "Inga andra personer i detta samtal",
-    "Your screen" : "Din skärm",
-    "Conversation, " : "Konversation, ",
-    "Contacts" : "Kontakter",
-    "Contacts, groups and circles" : "Kontakter, grupper och cirklar",
-    "Contacts and groups" : "Kontakter och grupper",
-    "Contacts and circles" : "Kontakter och cirklar",
-    "Loading contacts" : "Laddar kontakter",
-    "Select participants" : "Välj deltagare",
-    "Search conversations or contacts" : "Sök konversationer eller kontakter",
-    "[Unknown user name]" : "[Okänt användarnam]",
-    "Participant settings" : "Deltagarinställningar",
-    "Search for more contacts" : "Sök efter fler kontakter",
-    "Contacts loading" : "Laddar kontakter",
-    "Add participants to the conversation" : "Lägg till deltagare i konversationen",
-    "Add contacts" : "Lägg till kontakter",
-    "Add contacts, groups or circles" : "Lägg till kontakter, grupper och cirklar",
-    "Add contacts or groups" : "Lägg till kontakter eller grupper",
-    "Add contacts or circles" : "Lägg till kontakter eller cirklar",
-    "Guests" : "Gäster",
-    "Share link" : "Dela länk",
-    "Webinar" : "Webinar",
-    "Projects" : "Projekt",
-    "Limit app usage to groups." : "Begränsa appanvändning till grupper",
-    "Start calls" : "Starta samtal",
-    "Who can start a call?" : "Vem kan starta ett samtal?",
-    "Select a conversation to add to the project" : "Välj en konversation som ska läggas till i projektet",
-    "Please enter the password for this call" : "Vänligen ange lösenordet för detta samtal",
-    "Password required" : "Lösenord krävs",
-    "Cancel" : "Avbryt",
-    "Submit" : "Skicka",
     "Signaling server URL" : "Signalerar serverwebbadress",
+    "UDP and TCP" : "UDP och TCP",
+    "UDP only" : "endast UDP",
+    "TCP only" : "endast TCP",
     "This conversation is read only" : "Denna konversation är skrivskyddad",
+    "Conversation, " : "Konversation, ",
     "Default location for attachments" : "Standardplats för bilagor",
     "Select default location for attachments" : "Välj standardplats för bilagor",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call" : "Nextcloud Talk uppdaterades, du måste ladda om sidan innan du kan starta eller gå med i ett samtal"
+    "Participant settings" : "Deltagarinställningar",
+    "Add participants to the conversation" : "Lägg till deltagare i konversationen",
+    "Projects" : "Projekt",
+    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call" : "Nextcloud Talk uppdaterades, du måste ladda om sidan innan du kan starta eller gå med i ett samtal",
+    "Share link" : "Dela länk",
+    "Select a conversation to add to the project" : "Välj en konversation som ska läggas till i projektet",
+    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Webbläsaren du använder stöds inte av Nextcloud Talk. Använd den senaste versionen av Mozilla Firefox, Microsoft Edge, Google Chrome eller Apple Safari.",
+    "Error while uploading file" : "Fel vid uppladdning av fil",
+    "New in Talk 10" : "Nytt i Talk 10",
+    "Enabled" : "Aktiverad"
 },
 "nplurals=2; plural=(n != 1);");
