@@ -70,6 +70,7 @@ OC.L10N.register(
     "Share this link to invite others!" : "Поділіться цим посиланням з тими, кого бажаєте запросити!",
     "Show your screen" : "Демонстрація екрану",
     "Stop screensharing" : "Припинити демонстрацію екрану",
+    "Settings" : "Налаштування",
     "Dismiss" : "Припинити",
     "No audio" : "Вимкнути мікрофон",
     "Mute audio (m)" : "Вимкнути мікрофон (m)",
@@ -96,6 +97,12 @@ OC.L10N.register(
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
     "Enable lobby" : "Увімкнути схвалення входу",
+    "Save" : "Зберегти",
+    "Edit" : "Редагувати",
+    "Password" : "Пароль",
+    "Login" : "Login",
+    "Nickname" : "Прізвисько",
+    "Client ID" : "Ідентифікатор клієнта",
     "Chat notifications" : "Сповіщення чату",
     "Leave conversation" : "Залишити спілкування",
     "Delete conversation" : "Вилучити розмову",
@@ -105,7 +112,6 @@ OC.L10N.register(
     "Loading" : "Завантаження",
     "No search results" : "Відсутні результати",
     "Groups" : "Групи",
-    "Settings" : "Налаштування",
     "Create a new group conversation" : "Створити нову групову розмову",
     "Password protect" : "Захистити паролем",
     "Add participants" : "Додати учасників",
@@ -127,12 +133,6 @@ OC.L10N.register(
     "File to share" : "Виберіть файл для надання доступу",
     "Write message, @ to mention someone …" : "Написати повідомлення, @ім'я для згадки про користувача…",
     "Invalid path selected" : "Вибрано неправильний шлях",
-    "Enabled" : "Увімкнено",
-    "Save" : "Зберегти",
-    "Password" : "Пароль",
-    "Login" : "Login",
-    "Nickname" : "Прізвисько",
-    "Client ID" : "Ідентифікатор клієнта",
     "guest" : "гість",
     "Add users" : "Додати користувачів",
     "Add groups" : "Додати групи",
@@ -144,7 +144,6 @@ OC.L10N.register(
     "Add users or circles" : "Додати користувачів або кола",
     "Participants" : "Учасники",
     "Chat" : "Чат",
-    "Edit" : "Редагувати",
     "Keyboard shortcuts" : "Гарячі клавіші",
     "Search" : "Пошук",
     "Start call" : "Почати виклик",
@@ -164,21 +163,12 @@ OC.L10N.register(
     "The password is wrong. Try again." : "Пароль неправильний. Спробуйте ще раз.",
     "Android app" : "Застосунок для Android",
     "iOS app" : "Застосунок для iOS",
-    "Contacts" : "Контакти",
-    "Select participants" : "Виберіть учасників",
-    "Search conversations or contacts" : "Пошук розмов та контактів",
-    "Search for more contacts" : "Шукати більше контактів",
-    "Add participants to the conversation" : "Додати учасників до розмови",
-    "Guests" : "Гості",
-    "Share link" : "Поширити посилання",
-    "Projects" : "Проєкти",
-    "Start calls" : "Почати виклики",
-    "Who can start a call?" : "Хто може здійснювати виклики?",
-    "Select a conversation to add to the project" : "Виберіть розмову, яку потрібно додати до проєкту",
-    "Password required" : "Зазначте пароль",
-    "Cancel" : "Скасувати",
-    "Submit" : "Гаразд",
     "Default location for attachments" : "Типове розташування для вкладень",
-    "Select default location for attachments" : "Виберіть типове розташування для вкладень"
+    "Select default location for attachments" : "Виберіть типове розташування для вкладень",
+    "Add participants to the conversation" : "Додати учасників до розмови",
+    "Projects" : "Проєкти",
+    "Share link" : "Поширити посилання",
+    "Select a conversation to add to the project" : "Виберіть розмову, яку потрібно додати до проєкту",
+    "Enabled" : "Увімкнено"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
