@@ -91,9 +91,6 @@ OC.L10N.register(
     "A STUN server is used to determine the public IP address of participants behind a router." : "Máy chủ STUN được sử dụng để xác định địa chỉ IP công khai của người tham gia phía sau bộ định tuyến.",
     "TURN server URL" : "URL máy chủ TURN",
     "TURN server protocols" : "Giao thức máy chủ TURN",
-    "UDP and TCP" : "UDP và TCP",
-    "UDP only" : "Chỉ UDP",
-    "TCP only" : "Chỉ TCP",
     "Copy link" : "Sao chép liên kết",
     "Waiting for others to join the call …" : "Đang chờ người khác tham gia cuộc gọi…",
     "You can invite others in the participant tab of the sidebar" : "Bạn có thể mời những người khác trong tab người tham gia của thanh bên",
@@ -101,6 +98,7 @@ OC.L10N.register(
     "Share this link to invite others!" : "Chia sẻ liên kết này để mời những người khác!",
     "Show your screen" : "Hiện màn hình của bạn",
     "Stop screensharing" : "Ngừng chia sẽ màn hình",
+    "Settings" : "Thiết lập",
     "Dismiss" : "Bỏ qua",
     "No audio" : "Không có âm thanh",
     "Mute audio (m)" : "Tắt âm thành (m)",
@@ -123,6 +121,12 @@ OC.L10N.register(
     "Favorite" : "Ưa thích",
     "Password protection" : "Password protection",
     "Enter a password" : "Nhập mật khẩu",
+    "Save" : "Lưu",
+    "Edit" : "Chỉnh sửa",
+    "Password" : "Mật khẩu",
+    "API token" : "Tín chỉ API",
+    "Login" : "Login",
+    "Nickname" : "Biệt danh",
     "Leave conversation" : "Rời khỏi cuộc đàm thoại",
     "Delete conversation" : "Xóa đàm thoại",
     "Remove from favorites" : "Xóa khỏi ưa thích",
@@ -130,7 +134,6 @@ OC.L10N.register(
     "Loading" : "Đang tải",
     "Groups" : "Nhóm",
     "Circles" : "Vòng kết nối",
-    "Settings" : "Thiết lập",
     "Password protect" : "Mật khẩu bảo vệ",
     "Close" : "Đóng",
     "Conversation name" : "Tên đàm thoại",
@@ -141,12 +144,6 @@ OC.L10N.register(
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Send message" : "Gửi thông điệp",
     "File to share" : "Tệp để chia sẻ",
-    "Enabled" : "Bật",
-    "Save" : "Lưu",
-    "Password" : "Mật khẩu",
-    "API token" : "Tín chỉ API",
-    "Login" : "Login",
-    "Nickname" : "Biệt danh",
     "moderator" : "Người kiểm duyệt",
     "Demote from moderator" : "Hạ uy tín từ người kiểm duyệt",
     "Promote to moderator" : "Giới thiệu người kiểm duyệt",
@@ -155,7 +152,6 @@ OC.L10N.register(
     "Add users or groups" : "Add users or groups",
     "Participants" : "Người tham gia",
     "Chat" : "Trò chuyện",
-    "Edit" : "Chỉnh sửa",
     "Keyboard shortcuts" : "Phím tắt",
     "Search" : "Tìm",
     "Start call" : "Bắt đầu cuộc gọi",
@@ -181,16 +177,12 @@ OC.L10N.register(
     "Android app" : "Ứng dụng Android",
     "iOS app" : "Ứng dụng IOS",
     "{user} wants to talk with you" : "{user} muốn nói chuyện với bạn",
-    "No other people in this call" : "Không có người nào trong cuộc gọi này",
-    "Your screen" : "Màn hình của bạn",
-    "Contacts" : "Liên hệ",
-    "[Unknown user name]" : "[Tên người dùng chưa biết]",
-    "Share link" : "Chia sẽ liên kết",
+    "Signaling server URL" : "URL máy chủ đăng ký",
+    "UDP and TCP" : "UDP và TCP",
+    "UDP only" : "Chỉ UDP",
+    "TCP only" : "Chỉ TCP",
     "Projects" : "Dự án",
-    "Please enter the password for this call" : "Hãy nhập một mật khẩu cho cuộc gọi này",
-    "Password required" : "Mật khẩu đã được yêu cầu",
-    "Cancel" : "Hủy bỏ",
-    "Submit" : "Gửi đi",
-    "Signaling server URL" : "URL máy chủ đăng ký"
+    "Share link" : "Chia sẽ liên kết",
+    "Enabled" : "Bật"
 },
 "nplurals=1; plural=0;");
