@@ -13,9 +13,24 @@ OC.L10N.register(
     "{actor} invited you to {call}" : "{actor} 要請你加入{call}",
     "Talk" : "交談",
     "Guest" : "訪客",
+    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "歡迎來到Nextcloud Talk!\n在此對話中，您將了解關於Nextcloud Talk中可用的新功能。 ",
+    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "現在可以使用Microsoft Edge和Safari參加語音和視訊通話 ",
+    "- You can now notify all participants by posting \"@all\" into the chat" : "您現在可以通過在聊天室中張貼“ @all”來通知所有參與者",
+    "- With the \"arrow-up\" key you can repost your last message" : "使用“上”鍵，您可以重新發布上一條訊息",
+    "- You can now search for chats and messages in the unified search in the top bar" : "您現在可以搜索聊天和訊息在頂部欄的搜索",
+    "- Spice up your messages with emojis from the emoji picker" : "使用表情符號選擇器中的表情符號來豐富您的訊息",
+    "- You can now change your camera and microphone while being in a call" : "您可以在通話時更改相機和麥克風 ",
+    "- See a read status and send failed messages again" : "查看讀取狀態並再次發送失敗的訊息",
+    "- Raise your hand in a call with the R key" : "使用R鍵在通話中舉手",
+    "There are currently no commands available." : "當前沒有可用的命令.",
+    "The command does not exist" : "該命令不存在",
+    "An error occurred while running the command. Please ask an administrator to check the logs." : "運行命令時發生錯誤。 請要求管理員檢查日誌。 ",
     "You created the conversation" : "你建立了對話",
+    "You removed the description" : "您刪除了描述",
+    "An administrator removed the description" : "管理員刪除了描述",
     "You started a call" : "您發起了一通話",
     "You left the call" : "你離開了通話",
+    "An administrator locked the conversation" : "管理員鎖定了對話",
     "Join call" : "加入通話",
     "Open settings" : "開啟設定",
     "Andorra" : "安道爾",
@@ -254,11 +269,9 @@ OC.L10N.register(
     "Expired" : "已過期",
     "Validate SSL certificate" : "驗證 SSL憑證",
     "Saved" : "儲存",
-    "UDP and TCP" : "UDP 和 TCP",
-    "UDP only" : "僅UDP",
-    "TCP only" : "僅TCP",
     "Copy link" : "複製連結",
     "Waiting for others to join the call …" : "等待其他人加入通話...",
+    "Settings" : "設定",
     "Dismiss" : "取消",
     "Mute audio (m)" : "靜音 (m)",
     "Mute audio" : "靜音",
@@ -268,13 +281,19 @@ OC.L10N.register(
     "Favorite" : "我的最愛",
     "Password protection" : "密碼保護",
     "Enter a password" : "輸入密碼",
+    "Save" : "儲存",
+    "Edit" : "編輯",
+    "Password" : "密碼",
+    "API token" : "API token",
+    "Login" : "帳號",
+    "Nickname" : "暱稱",
+    "Client ID" : "客戶端ID",
     "Leave conversation" : "離開對話",
     "Delete conversation" : "刪除對話",
     "Remove from favorites" : "取消我的最愛",
     "Add to favorites" : "加到我的最愛",
     "Loading" : "載入中",
     "Groups" : "群組",
-    "Settings" : "設定",
     "Create a new group conversation" : "建立新群組對話",
     "Password protect" : "密碼防護",
     "Close" : "關閉",
@@ -288,20 +307,12 @@ OC.L10N.register(
     "Send message" : "傳送訊息",
     "File to share" : "要分享的檔案",
     "Invalid path selected" : "所選的路徑無效",
-    "Enabled" : "已啟用",
-    "Save" : "儲存",
-    "Password" : "密碼",
-    "API token" : "API token",
-    "Login" : "帳號",
-    "Nickname" : "暱稱",
-    "Client ID" : "客戶端ID",
     "moderator" : "主持人",
     "guest" : "訪客",
     "No results" : "沒有符合搜尋的項目",
     "Add users or groups" : "增加使用者或者群組",
     "Participants" : "參與者",
     "Chat" : "聊天",
-    "Edit" : "編輯",
     "Keyboard shortcuts" : "快速鍵",
     "Search" : "搜尋",
     "Start call" : "通話",
@@ -317,15 +328,11 @@ OC.L10N.register(
     "The password is wrong. Try again." : "密碼錯誤，請重試",
     "Android app" : "安卓應用",
     "iOS app" : "蘋果應用",
-    "Contacts" : "聯絡人",
-    "Search conversations or contacts" : "搜尋對話或聯絡人",
-    "[Unknown user name]" : "[未知的使用者名稱]",
-    "Guests" : "訪客",
-    "Share link" : "分享連結",
+    "UDP and TCP" : "UDP 和 TCP",
+    "UDP only" : "僅UDP",
+    "TCP only" : "僅TCP",
     "Projects" : "專案項目",
-    "Limit app usage to groups." : "限制群組的使用率:",
-    "Password required" : "請輸入密碼",
-    "Cancel" : "取消",
-    "Submit" : "送出"
+    "Share link" : "分享連結",
+    "Enabled" : "已啟用"
 },
 "nplurals=1; plural=0;");
