@@ -68,12 +68,15 @@ class Capabilities implements IPublicCapability {
 				'last-room-activity',
 				'no-ping',
 				'system-messages',
+				'delete-messages',
 				'mention-flag',
 				'in-call-flags',
+				'conversation-call-flags',
 				'notification-levels',
 				'invite-groups-and-mails',
 				'locked-one-to-one-rooms',
 				'read-only-rooms',
+				'listable-rooms',
 				'chat-read-marker',
 				'webinary-lobby',
 				'start-call-flag',
@@ -82,6 +85,11 @@ class Capabilities implements IPublicCapability {
 				'force-mute',
 				'conversation-v3',
 				'sip-support',
+				'chat-read-status',
+				'phonebook-search',
+				'raise-hand',
+				'room-description',
+				'rich-object-sharing',
 			],
 			'config' => [
 				'attachments' => [
@@ -89,18 +97,22 @@ class Capabilities implements IPublicCapability {
 				],
 				'chat' => [
 					'max-length' => ChatManager::MAX_CHAT_LENGTH,
+					'read-privacy' => Participant::PRIVACY_PUBLIC,
 				],
 				'conversations' => [],
+				'previews' => [
+					'max-gif-size' => (int)$this->serverConfig->getAppValue('spreed', 'max-gif-size', '3145728')
+				],
 			],
 		];
 
 		if ($user instanceof IUser) {
 			$capabilities['config']['attachments']['folder'] = $this->talkConfig->getAttachmentFolder($user->getUID());
+			$capabilities['config']['chat']['read-privacy'] = $this->talkConfig->getUserReadPrivacy($user->getUID());
 		}
 
 		$capabilities['config']['conversations']['can-create'] = $user instanceof IUser && !$this->talkConfig->isNotAllowedToCreateConversations($user);
 
-
 		if ($this->serverConfig->getAppValue('spreed', 'has_reference_id', 'no') === 'yes') {
 			$capabilities['features'][] = 'chat-reference-id';
 		}
