@@ -65,6 +65,13 @@ class Config {
 		return \is_array($groups) ? $groups : [];
 	}
 
+	public function getUserReadPrivacy(string $userId): int {
+		return (int) $this->config->getUserValue(
+			$userId,
+			'spreed', 'read_status_privacy',
+			(string) Participant::PRIVACY_PUBLIC);
+	}
+
 	/**
 	 * @return string[]
 	 */
@@ -236,6 +243,10 @@ class Config {
 			return [];
 		}
 
+		foreach ($servers as $key => $server) {
+			$servers[$key]['schemes'] = $server['schemes'] ?? 'turn';
+		}
+
 		return $servers;
 	}
 
@@ -249,6 +260,7 @@ class Config {
 
 		if (empty($servers)) {
 			return [
+				'schemes' => '',
 				'server' => '',
 				'username' => '',
 				'password' => '',
@@ -271,6 +283,7 @@ class Config {
 		$password = base64_encode(hash_hmac('sha1', $username, $server['secret'], true));
 
 		return [
+			'schemes' => $server['schemes'],
 			'server' => $server['server'],
 			'username' => $username,
 			'password' => $password,
