@@ -29,6 +29,7 @@ use OCA\Talk\Chat\AutoComplete\Sorter;
 use OCA\Talk\Chat\ChatManager;
 use OCA\Talk\Chat\MessageParser;
 use OCA\Talk\GuestManager;
+use OCA\Talk\MatterbridgeManager;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\Message;
 use OCA\Talk\Model\Session;
@@ -50,6 +51,8 @@ use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IL10N;
 use OCP\IRequest;
 use OCP\IUserManager;
+use OCP\RichObjectStrings\InvalidObjectExeption;
+use OCP\RichObjectStrings\IValidator;
 use OCP\User\Events\UserLiveStatusEvent;
 use OCP\UserStatus\IManager as IUserStatusManager;
 use OCP\UserStatus\IUserStatus;
@@ -92,6 +95,9 @@ class ChatController extends AEnvironmentAwareController {
 	/** @var IUserStatusManager */
 	private $statusManager;
 
+	/** @var MatterbridgeManager */
+	protected $matterbridgeManager;
+
 	/** @var SearchPlugin */
 	private $searchPlugin;
 
@@ -104,6 +110,9 @@ class ChatController extends AEnvironmentAwareController {
 	/** @var IEventDispatcher */
 	protected $eventDispatcher;
 
+	/** @var IValidator */
+	protected $richObjectValidator;
+
 	/** @var IL10N */
 	private $l;
 
@@ -120,10 +129,12 @@ class ChatController extends AEnvironmentAwareController {
 								MessageParser $messageParser,
 								IManager $autoCompleteManager,
 								IUserStatusManager $statusManager,
+								MatterbridgeManager $matterbridgeManager,
 								SearchPlugin $searchPlugin,
 								ISearchResult $searchResult,
 								ITimeFactory $timeFactory,
 								IEventDispatcher $eventDispatcher,
+								IValidator $richObjectValidator,
 								IL10N $l) {
 		parent::__construct($appName, $request);
 
@@ -138,13 +149,63 @@ class ChatController extends AEnvironmentAwareController {
 		$this->messageParser = $messageParser;
 		$this->autoCompleteManager = $autoCompleteManager;
 		$this->statusManager = $statusManager;
+		$this->matterbridgeManager = $matterbridgeManager;
 		$this->searchPlugin = $searchPlugin;
 		$this->searchResult = $searchResult;
 		$this->timeFactory = $timeFactory;
 		$this->eventDispatcher = $eventDispatcher;
+		$this->richObjectValidator = $richObjectValidator;
 		$this->l = $l;
 	}
 
+	protected function getActorInfo(string $actorDisplayName = ''): array {
+		if ($this->userId === null) {
+			$actorType = Attendee::ACTOR_GUESTS;
+			$sessionId = $this->session->getSessionForRoom($this->room->getToken());
+			// The character limit for actorId is 64, but the spreed-session is
+			// 256 characters long, so it has to be hashed to get an ID that
+			// fits (except if there is no session, as the actorId should be
+			// empty in that case but sha1('') would generate a hash too
+			// instead of returning an empty string).
+			$actorId = $sessionId ? sha1($sessionId) : 'failed-to-get-session';
+
+			if ($sessionId && $actorDisplayName) {
+				$this->guestManager->updateName($this->room, $this->participant, $actorDisplayName);
+			}
+		} else {
+			$actorType = Attendee::ACTOR_USERS;
+			$actorId = $this->userId;
+		}
+
+		return [$actorType, $actorId];
+	}
+
+	public function parseCommentToResponse(IComment $comment, Message $parentMessage = null): DataResponse {
+		$chatMessage = $this->messageParser->createMessage($this->room, $this->participant, $comment, $this->l);
+		$this->messageParser->parseMessage($chatMessage);
+
+		if (!$chatMessage->getVisibility()) {
+			$response = new DataResponse([], Http::STATUS_CREATED);
+			if ($this->participant->getAttendee()->getReadPrivacy() === Participant::PRIVACY_PUBLIC) {
+				$response->addHeader('X-Chat-Last-Common-Read', $this->chatManager->getLastCommonReadMessage($this->room));
+			}
+			return $response;
+		}
+
+		$this->participantService->updateLastReadMessage($this->participant, (int) $comment->getId());
+
+		$data = $chatMessage->toArray();
+		if ($parentMessage instanceof Message) {
+			$data['parent'] = $parentMessage->toArray();
+		}
+
+		$response = new DataResponse($data, Http::STATUS_CREATED);
+		if ($this->participant->getAttendee()->getReadPrivacy() === Participant::PRIVACY_PUBLIC) {
+			$response->addHeader('X-Chat-Last-Common-Read', $this->chatManager->getLastCommonReadMessage($this->room));
+		}
+		return $response;
+	}
+
 	/**
 	 * @PublicPage
 	 * @RequireParticipant
@@ -165,24 +226,7 @@ class ChatController extends AEnvironmentAwareController {
 	 *         found".
 	 */
 	public function sendMessage(string $message, string $actorDisplayName = '', string $referenceId = '', int $replyTo = 0): DataResponse {
-		if ($this->userId === null) {
-			$actorType = Attendee::ACTOR_GUESTS;
-			$sessionId = $this->session->getSessionForRoom($this->room->getToken());
-			// The character limit for actorId is 64, but the spreed-session is
-			// 256 characters long, so it has to be hashed to get an ID that
-			// fits (except if there is no session, as the actorId should be
-			// empty in that case but sha1('') would generate a hash too
-			// instead of returning an empty string).
-			$actorId = $sessionId ? sha1($sessionId) : 'failed-to-get-session';
-
-			if ($sessionId && $actorDisplayName) {
-				$this->guestManager->updateName($this->room, $this->participant, $actorDisplayName);
-			}
-		} else {
-			$actorType = Attendee::ACTOR_USERS;
-			$actorId = $this->userId;
-		}
-
+		[$actorType, $actorId] = $this->getActorInfo($actorDisplayName);
 		if (!$actorId) {
 			return new DataResponse([], Http::STATUS_NOT_FOUND);
 		}
@@ -214,20 +258,69 @@ class ChatController extends AEnvironmentAwareController {
 			return new DataResponse([], Http::STATUS_BAD_REQUEST);
 		}
 
-		$chatMessage = $this->messageParser->createMessage($this->room, $this->participant, $comment, $this->l);
-		$this->messageParser->parseMessage($chatMessage);
+		return $this->parseCommentToResponse($comment, $parentMessage);
+	}
 
-		if (!$chatMessage->getVisibility()) {
-			return new DataResponse([], Http::STATUS_CREATED);
+	/**
+	 * @PublicPage
+	 * @RequireParticipant
+	 * @RequireReadWriteConversation
+	 * @RequireModeratorOrNoLobby
+	 *
+	 * Sends a rich-object to the given room.
+	 *
+	 * The author and timestamp are automatically set to the current user/guest
+	 * and time.
+	 *
+	 * @param string $objectType
+	 * @param string $objectId
+	 * @param string $metaData
+	 * @param string $actorDisplayName
+	 * @param string $referenceId
+	 * @return DataResponse the status code is "201 Created" if successful, and
+	 *         "404 Not found" if the room or session for a guest user was not
+	 *         found".
+	 */
+	public function shareObjectToChat(string $objectType, string $objectId, string $metaData = '', string $actorDisplayName = '', string $referenceId = ''): DataResponse {
+		[$actorType, $actorId] = $this->getActorInfo($actorDisplayName);
+		if (!$actorId) {
+			return new DataResponse([], Http::STATUS_NOT_FOUND);
 		}
 
-		$this->participantService->updateLastReadMessage($this->participant, (int) $comment->getId());
-
-		$data = $chatMessage->toArray();
-		if ($parentMessage instanceof Message) {
-			$data['parent'] = $parentMessage->toArray();
+		$data = $metaData !== '' ? json_decode($metaData, true) : [];
+		if (!is_array($data)) {
+			$data = [];
 		}
-		return new DataResponse($data, Http::STATUS_CREATED);
+		$data['type'] = $objectType;
+		$data['id'] = $objectId;
+
+		try {
+			$this->richObjectValidator->validate('{object}', ['object' => $data]);
+		} catch (InvalidObjectExeption $e) {
+			return new DataResponse([], Http::STATUS_BAD_REQUEST);
+		}
+
+		$this->participantService->ensureOneToOneRoomIsFilled($this->room);
+		$creationDateTime = $this->timeFactory->getDateTime('now', new \DateTimeZone('UTC'));
+
+		$message = json_encode([
+			'message' => 'object_shared',
+			'parameters' => [
+				'objectType' => $objectType,
+				'objectId' => $objectId,
+				'metaData' => $data,
+			],
+		]);
+
+		try {
+			$comment = $this->chatManager->addSystemMessage($this->room, $actorType, $actorId, $message, $creationDateTime, true, $referenceId);
+		} catch (MessageTooLongException $e) {
+			return new DataResponse([], Http::STATUS_REQUEST_ENTITY_TOO_LARGE);
+		} catch (\Exception $e) {
+			return new DataResponse([], Http::STATUS_BAD_REQUEST);
+		}
+
+		return $this->parseCommentToResponse($comment);
 	}
 
 	/**
@@ -266,6 +359,9 @@ class ChatController extends AEnvironmentAwareController {
 	 * @param int $lookIntoFuture Polling for new messages (1) or getting the history of the chat (0)
 	 * @param int $limit Number of chat messages to receive (100 by default, 200 at most)
 	 * @param int $lastKnownMessageId The last known message (serves as offset)
+	 * @param int $lastCommonReadId The last known common read message
+	 *                              (so the response is 200 instead of 304 when
+	 *                              it changes even when there are no messages)
 	 * @param int $timeout Number of seconds to wait for new messages (30 by default, 30 at most)
 	 * @param int $setReadMarker Automatically set the last read marker when 1,
 	 *                           if your client does this itself via chat/{token}/read set to 0
@@ -278,7 +374,14 @@ class ChatController extends AEnvironmentAwareController {
 	 *         'actorDisplayName', 'timestamp' (in seconds and UTC timezone) and
 	 *         'message'.
 	 */
-	public function receiveMessages(int $lookIntoFuture, int $limit = 100, int $lastKnownMessageId = 0, int $timeout = 30, int $setReadMarker = 1, int $includeLastKnown = 0, int $noStatusUpdate = 0): DataResponse {
+	public function receiveMessages(int $lookIntoFuture,
+									int $limit = 100,
+									int $lastKnownMessageId = 0,
+									int $lastCommonReadId = 0,
+									int $timeout = 30,
+									int $setReadMarker = 1,
+									int $includeLastKnown = 0,
+									int $noStatusUpdate = 0): DataResponse {
 		$limit = min(200, $limit);
 		$timeout = min(30, $timeout);
 
@@ -333,7 +436,18 @@ class ChatController extends AEnvironmentAwareController {
 		}
 
 		if (empty($comments)) {
-			return new DataResponse([], Http::STATUS_NOT_MODIFIED);
+			$response = new DataResponse([], Http::STATUS_NOT_MODIFIED);
+			if ($lastCommonReadId && $this->participant->getAttendee()->getReadPrivacy() === Participant::PRIVACY_PUBLIC) {
+				$newLastCommonRead = $this->chatManager->getLastCommonReadMessage($this->room);
+				if ($lastCommonReadId !== $newLastCommonRead) {
+					// Set the status code to 200 so the header is sent to the client.
+					// As per "section 10.3.5 of RFC 2616" entity headers shall be
+					// stripped out on 304: https://stackoverflow.com/a/17822709
+					$response->setStatus(Http::STATUS_OK);
+				}
+				$response->addHeader('X-Chat-Last-Common-Read', $newLastCommonRead);
+			}
+			return $response;
 		}
 
 		$i = 0;
@@ -424,11 +538,77 @@ class ChatController extends AEnvironmentAwareController {
 			 * $this->participantService->updateLastReadMessage($this->participant, (int) $newLastKnown->getId());
 			 * }
 			 */
+			if ($this->participant->getAttendee()->getReadPrivacy() === Participant::PRIVACY_PUBLIC) {
+				$response->addHeader('X-Chat-Last-Common-Read', $this->chatManager->getLastCommonReadMessage($this->room));
+			}
 		}
 
 		return $response;
 	}
 
+	/**
+	 * @NoAdminRequired
+	 * @RequireParticipant
+	 * @RequireReadWriteConversation
+	 * @RequireModeratorOrNoLobby
+	 *
+	 * @param int $messageId
+	 * @return DataResponse
+	 */
+	public function deleteMessage(int $messageId): DataResponse {
+		try {
+			$message = $this->chatManager->getComment($this->room, (string) $messageId);
+		} catch (NotFoundException $e) {
+			return new DataResponse([], Http::STATUS_NOT_FOUND);
+		}
+
+		$attendee = $this->participant->getAttendee();
+		if (!$this->participant->hasModeratorPermissions(false)
+			&& ($message->getActorType() !== $attendee->getActorType()
+				|| $message->getActorId() !== $attendee->getActorId())) {
+			// Actor is not a moderator or not the owner of the message
+			return new DataResponse([], Http::STATUS_FORBIDDEN);
+		}
+
+		if ($message->getVerb() !== 'comment') {
+			// System message or file share (since the message is not parsed, it has type "system")
+			return new DataResponse([], Http::STATUS_METHOD_NOT_ALLOWED);
+		}
+
+		$maxDeleteAge = $this->timeFactory->getDateTime();
+		$maxDeleteAge->sub(new \DateInterval('PT6H'));
+		if ($message->getCreationDateTime() < $maxDeleteAge) {
+			// Message is too old
+			return new DataResponse([], Http::STATUS_BAD_REQUEST);
+		}
+
+		$systemMessageComment = $this->chatManager->deleteMessage(
+			$this->room,
+			$messageId,
+			$attendee->getActorType(),
+			$attendee->getActorId(),
+			$this->timeFactory->getDateTime()
+		);
+
+		$systemMessage = $this->messageParser->createMessage($this->room, $this->participant, $systemMessageComment, $this->l);
+		$this->messageParser->parseMessage($systemMessage);
+
+		$comment = $this->chatManager->getComment($this->room, (string) $messageId);
+		$message = $this->messageParser->createMessage($this->room, $this->participant, $comment, $this->l);
+		$this->messageParser->parseMessage($message);
+
+		$data = $systemMessage->toArray();
+		$data['parent'] = $message->toArray();
+
+		$bridge = $this->matterbridgeManager->getBridgeOfRoom($this->room);
+
+		$response = new DataResponse($data, $bridge['enabled'] ? Http::STATUS_ACCEPTED: Http::STATUS_OK);
+		if ($this->participant->getAttendee()->getReadPrivacy() === Participant::PRIVACY_PUBLIC) {
+			$response->addHeader('X-Chat-Last-Common-Read', $this->chatManager->getLastCommonReadMessage($this->room));
+		}
+		return $response;
+	}
+
 	/**
 	 * @NoAdminRequired
 	 * @RequireParticipant
@@ -438,7 +618,11 @@ class ChatController extends AEnvironmentAwareController {
 	 */
 	public function setReadMarker(int $lastReadMessage): DataResponse {
 		$this->participantService->updateLastReadMessage($this->participant, $lastReadMessage);
-		return new DataResponse();
+		$response = new DataResponse();
+		if ($this->participant->getAttendee()->getReadPrivacy() === Participant::PRIVACY_PUBLIC) {
+			$response->addHeader('X-Chat-Last-Common-Read', $this->chatManager->getLastCommonReadMessage($this->room));
+		}
+		return $response;
 	}
 
 	/**
